/*
 *  HtmlGutter.java
 *  Copyright (c) 2000, 2001, 2002 Andre Kaplan
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package code2html.html;


/**
 *  Description of the Class
 *
 *@author     lars
 *@created    March 31, 2003
 */
public class HtmlGutter {

	/**
	 *  Constructor for the HtmlGutter object
	 *
	 *@param  bgColor            Description of the Parameter
	 *@param  fgColor            Description of the Parameter
	 *@param  highlightColor     Description of the Parameter
	 *@param  highlightInterval  Description of the Parameter
	 */
	public HtmlGutter(
			String bgColor, String fgColor,
			String highlightColor, int highlightInterval
			) {
		this(4, bgColor, fgColor, highlightColor, highlightInterval);
	}


	/**
	 *  Constructor for the HtmlGutter object
	 *
	 *@param  gutterSize         Description of the Parameter
	 *@param  bgColor            Description of the Parameter
	 *@param  fgColor            Description of the Parameter
	 *@param  highlightColor     Description of the Parameter
	 *@param  highlightInterval  Description of the Parameter
	 */
	public HtmlGutter(
			int gutterSize,
			String bgColor, String fgColor,
			String highlightColor, int highlightInterval
			) {
		this.gutterSize = gutterSize;

		this.bgColor = bgColor;
		this.fgColor = fgColor;

		this.highlightColor = highlightColor;
		this.highlightInterval = highlightInterval;

		StringBuffer buf = new StringBuffer();
		for (int i = 0; i < this.gutterSize; i++) {
			buf.append(' ');
		}
		this.spacer = buf.toString();
	}


	/**
	 *  Constructor for the HtmlGutter object
	 */
	protected HtmlGutter() {
		this("#ffffff", "#8080c0", "#000000", 5);
	}


	/**
	 *  Gets the gutterBorderSize attribute of the HtmlGutter object
	 *
	 *@return    The gutterBorderSize value
	 */
	public int getGutterBorderSize() {
		return this.gutterBorderSize;
	}


	/**
	 *  Gets the gutterSize attribute of the HtmlGutter object
	 *
	 *@return    The gutterSize value
	 */
	public int getGutterSize() {
		return this.gutterSize;
	}


	/**
	 *  Gets the size attribute of the HtmlGutter object
	 *
	 *@return    The size value
	 */
	public int getSize() {
		return this.gutterSize + this.gutterBorderSize;
	}


	/**
	 *  Sets the gutterSize attribute of the HtmlGutter object
	 *
	 *@param  gutterSize  The new gutterSize value
	 */
	public void setGutterSize(int gutterSize) {
		this.gutterSize = gutterSize;

		StringBuffer buf = new StringBuffer();
		for (int i = 0; i < this.gutterSize; i++) {
			buf.append(' ');
		}
		this.spacer = buf.toString();
	}


	/**
	 *  Description of the Method
	 *
	 *@return    Description of the Return Value
	 */
	public String toCSS() {
		return "";
	}


	/**
	 *  Description of the Method
	 *
	 *@param  lineNumber  Description of the Parameter
	 *@return             Description of the Return Value
	 */
	public String toEmptyHTML(int lineNumber) {
		boolean highlighted = (
				(this.highlightInterval > 0)
				 && (lineNumber % this.highlightInterval == 0)
				);

		StringBuffer bufOpen = new StringBuffer();
		StringBuffer bufClose = new StringBuffer();

		if (highlighted) {
			bufOpen.append("<fo:inline")
					.append(" color=\"")
					.append(this.highlightColor)
					.append("\">");

		} else {
			bufOpen.append("<fo:inline")
					.append(" color=\"")
					.append(this.fgColor)
					.append("\">");
		}
		bufClose.insert(0, "</fo:inline>");

		/*
		 *  bufOpen.append("<font")
		 *  .append(" bgcolor=\"")
		 *  .append(this.bgColor)
		 *  .append("\">");
		 *  bufClose.insert(0, "</font>");
		 */
		StringBuffer buf = new StringBuffer();
		buf.append(bufOpen.toString())
				.append(spacer)
				.append(this.gutterBorder)
				.append(bufClose.toString());

		return buf.toString();
	}


	/**
	 *  Description of the Method
	 *
	 *@param  lineNumber  Description of the Parameter
	 *@return             Description of the Return Value
	 */
	public String toHTML(int lineNumber) {
		StringBuffer bufOpen = new StringBuffer();
		StringBuffer bufClose = new StringBuffer();

		if ((this.highlightInterval > 0)
				 && (lineNumber % this.highlightInterval == 0)
				) {
			bufOpen.append("<fo:inline")
					.append(" color=\"")
					.append(this.highlightColor)
					.append("\">");

		} else {
			bufOpen.append("<fo:inline")
					.append(" color=\"")
					.append(this.fgColor)
					.append("\">");
		}
		bufClose.insert(0, "</fo:inline>");

		/*
		 *  bufOpen.append("<font")
		 *  .append(" bgcolor=\"")
		 *  .append(this.bgColor)
		 *  .append("\">");
		 *  bufClose.insert(0, "</font>");
		 */
		StringBuffer buf = new StringBuffer();
		String s = Integer.toString(lineNumber);
		buf.append(bufOpen.toString())
				.append(spacer.substring(0, this.gutterSize - s.length()))
				.append(s)
				.append(':')
				.append(bufClose.toString());

		return buf.toString();
	}


	/**
	 *  Description of the Field
	 */
	protected String bgColor;
	/**
	 *  Description of the Field
	 */
	protected String fgColor;
	/**
	 *  Description of the Field
	 */
	protected char gutterBorder = ':';
	/**
	 *  Description of the Field
	 */
	protected int gutterBorderSize = 1;

	/**
	 *  Description of the Field
	 */
	protected int gutterSize;

	/**
	 *  Description of the Field
	 */
	protected String highlightColor;
	/**
	 *  Description of the Field
	 */
	protected int highlightInterval;

	/**
	 *  Description of the Field
	 */
	protected String spacer;
}

