/*
 *  Main.java
 *  Copyright (c) 2002 Andre Kaplan
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package code2html;
import code2html.html.HtmlCssStyle;
import code2html.html.HtmlDocument;
import code2html.html.HtmlGutter;
import code2html.html.HtmlPainter;
import code2html.html.HtmlStyle;
import code2html.syntax.ParserRuleSet;
import code2html.syntax.TokenMarker;
import code2html.syntax.XModeHandler;

import com.microstar.xml.*;

import java.awt.Color;
import java.awt.Font;

import java.io.*;
import java.util.Vector;

import javax.swing.text.Segment;
//import javax.xml.parsers.DocumentBuilder;
//import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.stream.*;

import org.gjt.sp.jedit.MiscUtilities;
import org.gjt.sp.jedit.syntax.ParserRule;
import org.gjt.sp.jedit.syntax.SyntaxStyle;
import org.gjt.sp.jedit.syntax.Token;
import org.gjt.sp.util.Log;

import org.w3c.dom.*;

import org.xml.sax.InputSource;

/**
 *  Description of the Class
 *
 *@author     lars
 *@created    March 31, 2003
 *
 * Modified by TP: default (fallback) behaviour is configurable:
 * just specify a second argument to the htmlSyntax method...
 */
public class Main {

	/**
	 *  The main program for the Main class
	 *
	 *@param  args  The command line arguments
	 */
	public static void main(String[] args) {
		Log.init(false, Log.ERROR);

		int exit = parseCommandLine(args);

		if (exit != 0) {
			usage();
		}

		System.exit(exit);
	}


	/**
	 *  Description of the Method
	 *
	 *@param  o  Description of the Parameter
	 *@return    Description of the Return Value
	 */
/*
	public static Object foSyntax(com.icl.saxon.expr.SingletonNodeSet o, String defaultMode) {
		return Syntax(o, false, defaultMode);
	}
*/
	/**
	 *  Description of the Method
	 *
	 *@param  o  Description of the Parameter
	 *@return    Description of the Return Value
	 */
	public static Object foSyntax(String pre, String role, String defaultMode, String lineNumbering) {
		return SyntaxToSource(pre, false, role, defaultMode, lineNumbering);
	}


	/**
	 *  Gets the property attribute of the Main class
	 *
	 *@param  name  Description of the Parameter
	 *@return       The property value
	 */
	public final static String getProperty(String name) {
		return propertyAccessor.getProperty(name);
	}


	/**
	 *  Gets the property attribute of the Main class
	 *
	 *@param  name  Description of the Parameter
	 *@param  def   Description of the Parameter
	 *@return       The property value
	 */
	public final static String getProperty(String name, String def) {
		return propertyAccessor.getProperty(name, def);
	}


	/**
	 *  Gets the property attribute of the Main class
	 *
	 *@param  name  Description of the Parameter
	 *@param  args  Description of the Parameter
	 *@return       The property value
	 */
	public final static String getProperty(String name, Object[] args) {
		return propertyAccessor.getProperty(name, args);
	}


	/**
	 *  Description of the Method
	 *
	 *@param  o  Description of the Parameter
	 *@return    Description of the Return Value
	 */
/*
	public static Object htmlSyntax(com.icl.saxon.expr.SingletonNodeSet o, String defaultMode) {
		return Syntax(o, true, defaultMode);
	}
*/
	/**
	 *  Description of the Method
	 *
	 *@param  o  Description of the Parameter
	 *@return    Description of the Return Value
	 */
	public static Object htmlSyntax(String pre, String role, String defaultMode, String lineNumbering) {
		return SyntaxToSource(pre, true, role, defaultMode, lineNumbering);
	}
	//}}}


	//{{{ markTokens() method
	/**
	 *  Mark tokens for the specified <code>Reader</code>
	 *
	 *@param  config       Description of the Parameter
	 *@param  tokenMarker  Description of the Parameter
	 *@param  r            Description of the Parameter
	 *@param  w            Description of the Parameter
	 */
	public static void markTokens(
			Config config, TokenMarker tokenMarker, Reader r, Writer w
			) {
		HtmlStyle style = config.getStyle();
		HtmlGutter gutter = config.getGutter();
		HtmlPainter painter = config.getPainter();

		try {
			BufferedReader reader = new BufferedReader(r);
			BufferedWriter writer = new BufferedWriter(w);

			HtmlDocument document = new HtmlDocument(
					Main.getProperty("view.bgColor", "#ffffff"),
					Main.getProperty("view.fgColor", "#000000"),
					painter.getSyntaxStyles(),
					style,
					gutter,
					"Code2HTML",
					System.getProperty("line.separator")
					);

			document.htmlOpen(writer);

			Segment seg = new Segment();
			String line = null;
			TokenMarker.LineContext context = null;

			for (int lineNumber = 1; (line = reader.readLine()) != null; lineNumber++) {
				TokenList tokenList = new TokenList();

				seg.offset = 0;
				seg.count = line.length();
				seg.array = line.toCharArray();

				/*
				 *  Prepare tokenization
				 */
				tokenList.lastToken = null;

				ParserRule oldRule;
				ParserRuleSet oldRules;
				if (context == null) {
					oldRule = null;
					oldRules = null;
				} else {
					oldRule = context.inRule;
					oldRules = context.rules;
				}

				context = tokenMarker.markTokens(context, tokenList, seg);
				SyntaxToken syntaxTokens = SyntaxTokenUtilities.convertTokens(
						tokenList.getFirstToken()
						);
				painter.setPos(0);
				painter.paintSyntaxLine(writer, lineNumber, seg, syntaxTokens);
				writer.newLine();
			}

			document.htmlClose(writer);

			writer.flush();
			writer.close();
		} catch (IOException ioe) {}
	}


	/**
	 *  Description of the Method
	 *
	 *@param  args  Description of the Parameter
	 *@return       Description of the Return Value
	 */
	public static int parseCommandLine(String[] args) {
		String scheme = null;
		String catalog = null;
		Vector files = new Vector();

		CommandLineConfig.Arguments arguments = new CommandLineConfig.Arguments();

		for (int i = 0; i < args.length; i++) {
			String arg = args[i];
			if ((arg == null) || (arg.length() == 0)) {
				continue;
			}

			if (arg.equals("--help")) {
				usage();
				return 0;
			} else if (arg.startsWith("--catalog=")) {
				catalog = arg.substring("--catalog=".length());
			} else if (arg.startsWith("--scheme=")) {
				scheme = arg.substring("--scheme=".length());
			} else if (arg.startsWith("--css=")) {
				String css = arg.substring("--css=".length()).toLowerCase();
				if ("yes".equals(css)) {
					arguments.useCSS = true;
				} else if ("no".equals(css)) {
					arguments.useCSS = false;
				} else {
					return 1;
				}
			} else if (arg.startsWith("--gutter=")) {
				String gutter = arg.substring("--gutter=".length()).toLowerCase();
				if ("yes".equals(gutter)) {
					arguments.showGutter = true;
				} else if ("no".equals(gutter)) {
					arguments.showGutter = false;
				} else {
					return 1;
				}
			} else if (arg.startsWith("--gutter-size=")) {
				String gutterSize = arg.substring("--gutter-size=".length());
				try {
					arguments.gutterSize = Integer.parseInt(gutterSize);
					if (arguments.gutterSize <= 0) {
						return 1;
					}
				} catch (NumberFormatException nfe) {
					return 1;
				}
			} else if (arg.startsWith("--tab-size=")) {
				String tabSize = arg.substring("--tab-size=".length());
				try {
					arguments.tabSize = Integer.parseInt(tabSize);
					if (arguments.tabSize <= 0) {
						return 1;
					}
				} catch (NumberFormatException nfe) {
					return 1;
				}
			} else if (arg.startsWith("--wrap=")) {
				String wrap = arg.substring("--wrap=".length());
				try {
					arguments.wrap = Integer.parseInt(wrap);
					if (arguments.wrap < 0) {
						return 1;
					}
				} catch (NumberFormatException nfe) {
					return 1;
				}
			} else {
				files.addElement(arg);
			}
		}

		if (catalog == null) {
			Log.log(Log.ERROR, Main.class, "--catalog option is mandatory");
			return 1;
		}

		try {
			loadScheme(scheme);
		} catch (FileNotFoundException fnfe) {
			Log.log(Log.ERROR, Main.class, fnfe);
			return 1;
		} catch (IOException ioe) {
			Log.log(Log.ERROR, Main.class, ioe);
			return 1;
		}

		loadXModeErrors();

		// loadModeCatalog(catalog, false); by TP, March 10, 2004
		loadModeCatalog(catalog, true);

		Mode[] modes = ModeUtilities.getModes();

		SyntaxStyle[] styles = StyleUtilities.loadStyles(propertyAccessor, "monospaced", 12, true);
		arguments.styles = styles;
		arguments.propertyAccessor = propertyAccessor;

		try {
			for (int i = 0; i < files.size(); i++) {

				Config config = new CommandLineConfig(arguments);

				String file = (String) files.elementAt(i);
				Mode mode = ModeUtilities.getMode("text");
				File f = new File(file);
				for (int j = 0; j < modes.length; j++) {
					if (modes[j].accept(f.getName(), "")) {
						mode = modes[j];
						break;
					}
				}

				if (mode == null) {
					Log.log(
							Log.WARNING, Main.class, "Could not find mode for [" + file + "]"
							);
					continue;
				}

				Reader reader = new FileReader(file);
				Writer writer = new FileWriter(file + ".html");

				markTokens(config, mode.getTokenMarker(), reader, writer);
			}
		} catch (IOException ioe) {
			Log.log(Log.ERROR, Main.class, ioe);
			return 1;
		}

		return 0;
	}


	/**
	 *  Description of the Method
	 */
	public static void usage() {
		System.out.println("Usage: java code2html.Main OPTION... --catalog=FILE FILE...");
		System.out.println();
		System.out.println("Options:");
		System.out.println("  --help             print this help file");
		System.out.println("  --scheme=FILE      scheme file");
		System.out.println("  --css=yes|no       use cascading style sheets. Default: [yes]");
		System.out.println("  --gutter=yes|no    display line number. Default: [yes]");
		System.out.println("  --gutter-size=INT  gutter size > 0. Default: [3]");
		System.out.println("  --tab-size=INT     tab size > 0. Default: [8]");
		System.out.println("  --wrap=INT         line wrapping. Default: [0]");
	}


	/**
	 *  Description of the Method
	 *
	 *@param  o     Description of the Parameter
	 *@param  html  Description of the Parameter
	 *@return       Description of the Return Value
	 */
	private static Object SyntaxToSource(String pre, boolean html, String role, 
					     String defaultMode, String lineNumbering) {
		StringBuffer puf = new StringBuffer("");

		try {
			puf.append("85\n");
			loadXModeErrors();

			loadModeCatalog("conf" + java.io.File.separator + "modes" + java.io.File.separator + "catalog", true); // changed to true by TP, March 10, 2004

			puf.append("90\n");
			//puf.append("text");
			Mode mode = ModeUtilities.getMode("text");
			String post;
			puf.append("95\n");
			/*
			Node node = null;
			int count = o.getCount();
			puf.append(count);
			for (int i = 0; i < count; i++) {
				puf.append("100\n");
				node = o.item(i);
				pre = node.getNodeValue();
			}
			*/
			puf.append("pre: " + pre + "\n");
			puf.append("105\n");
			String scheme = null;
			String catalog = null;
			Vector files = new Vector();

			puf.append("110\n");
			CommandLineConfig.Arguments arguments = new CommandLineConfig.Arguments();
			//replaceable
			arguments.useCSS = html;
			arguments.showGutter = false;
			puf.append("115\n");
			try {
				puf.append("testing gutter\n");
				//if (((Element) node.getParentNode()).getAttribute("linenumbering").equals("numbered")) {
				if ("numbered".equals(lineNumbering)) {
					arguments.showGutter = true;
					puf.append("120\n");
				}
			} catch (Exception e) {
				arguments.showGutter = false;

				puf.append("125\n");
			}
			try {
				puf.append("testing role\n");
				//Element parent = ((Element) node.getParentNode());
				//Log.log(Log.DEBUG, Main.class, parent);
				
				String mod = role; // changed by TP, orig. parent.getAttribute("role");
				Log.log(Log.DEBUG, Main.class, mod);
				mode = ModeUtilities.getMode(mod);
				puf.append("mode:" + mode.toString() + "\n");
				puf.append("130\n");
			} catch (Exception e) {
			    if (defaultMode == null || defaultMode.trim().equals(""))
			        defaultMode = "text";
				mode = ModeUtilities.getMode(defaultMode);
				Log.log(Log.ERROR, Main.class, "Fallling back to mode "+defaultMode);
			}

			puf.append("135\n");
			try {
				loadScheme("conf" + java.io.File.separator + "default.scheme");
			} catch (FileNotFoundException fnfe) {
				Log.log(Log.ERROR, Main.class, puf);
				Log.log(Log.ERROR, Main.class, fnfe);
				puf.append("140\n");
				return pre;
				//return puf.toString();
			} catch (IOException ioe) {
				Log.log(Log.ERROR, Main.class, puf);
				Log.log(Log.ERROR, Main.class, ioe);

				puf.append("145\n");
				return pre;
				//return puf.toString();
			}

			//loadXModeErrors();
			puf.append("150\n");
			//loadModeCatalog("conf" + java.io.File.separator + "modes" + java.io.File.separator + "catalog", false);

			SyntaxStyle[] styles = StyleUtilities.loadStyles(propertyAccessor, "monospaced", 12, true);
			arguments.styles = styles;
			puf.append("155\n");
			arguments.propertyAccessor = propertyAccessor;

			Reader reader = new StringReader(pre);
			Writer writer = new StringWriter();
			
			puf.append("160\n");

			Config config = new CommandLineConfig(arguments);
			puf.append("161\n");
			Log.log(Log.ERROR, Main.class, mode);
			
			// the key method!!!
			markTokens(config, mode.getTokenMarker(), reader, writer);
			
			puf.append("165\n");

			post = writer.toString();

			puf.append("170\n");
			puf.append(post);
			try {
			//	System.setProperty("javax.xml.parsers.DocumentBuilderFactory", "com.icl.saxon.om.DocumentBuilderFactoryImpl");
			//	DocumentBuilderFactory dfactory = DocumentBuilderFactory.newInstance();
				puf.append("175\n");
			//	dfactory.setNamespaceAware(true);

			//	DocumentBuilder docBuilder = dfactory.newDocumentBuilder();
				Reader postreader = new StringReader(post);
				puf.append("180\n");
			//	Node doc = docBuilder.parse(new InputSource(postreader));
			
				// post (-processed) string to reader and to StreamSource
				return new StreamSource(postreader);
			//	return doc;
			} catch (Exception e) {
				Log.log(Log.ERROR, Main.class, puf);
				Log.log(Log.ERROR, Main.class, e);
				puf.append("185\n");
				return pre;
				//return puf.toString();
			}
		} catch (Exception e) {
			puf.append("190\n");
			Log.log(Log.ERROR, Main.class, puf);
			Log.log(Log.ERROR, Main.class, e);
			//e.printStackTrace();
			//System.out.println(puf);
			//return puf.toString();
			return pre;
		}
	}


	//{{{ loadModeCatalog() method
	/**
	 *  Loads a mode catalog file.
	 *
	 *@param  path      Description of the Parameter
	 *@param  resource  Description of the Parameter
	 *@since            jEdit 3.2pre2
	 */
	private static void loadModeCatalog(String path, boolean resource) {
		//Log.log(Log.MESSAGE, Main.class, "Loading mode catalog file " + path);
        System.err.println("Loading mode catalog file " + path);
        
		ModeCatalogHandler handler = new ModeCatalogHandler(
				MiscUtilities.getParentOfPath(path), resource);
		XmlParser parser = new XmlParser();
		parser.setHandler(handler);
		try {
			InputStream _in;
			if (resource) {
				_in = Main.class.getResourceAsStream(path);
			} else {

  			    _in = new FileInputStream(path);
				
			}
			BufferedReader in = new BufferedReader(
					new InputStreamReader(_in));
			parser.parse(null, null, in);
		} catch (XmlException xe) {
			int line = xe.getLine();
			String message = xe.getMessage();
			Log.log(Log.ERROR, Main.class, path + ":" + line
					 + ": " + message);
		} catch (Exception e) {
			Log.log(Log.ERROR, Main.class, e);
		}
	}


	/**
	 *  Description of the Method
	 *
	 *@param  scheme                     Description of the Parameter
	 *@exception  FileNotFoundException  Description of the Exception
	 *@exception  IOException            Description of the Exception
	 */
	private static void loadScheme(String scheme)
			 throws FileNotFoundException, IOException {
		InputStream in = null;

		if (scheme == null) {
			in = Main.class.getResourceAsStream(
					"/schemes/default.jedit-scheme"
					);
		} else {
		    try {
			    in = new FileInputStream(scheme);
			    
			} catch(FileNotFoundException fnfe) {
			    
			    System.err.println("Try to load scheme "+scheme);
			    
			    in = Main.class.getResourceAsStream(scheme);
			    
			    System.err.println("... loaded scheme as "+in);
			}
		}

		propertyAccessor.loadProps(in);
	}


	/**
	 *  Description of the Method
	 */
	private static void loadXModeErrors() {
		//{{{ XMode errors
		propertyAccessor.setProperty(
				"xmode-error.title",
				"XML Parse Error"
				);
		// {2} is the column number, but it's not too useful so we don't show it
		propertyAccessor.setProperty(
				"xmode-error.message",
				"An error occurred while parsing {0}, line {1}:\n\t{3}"
				);
		propertyAccessor.setProperty(
				"xmode-error.dtd", "The DTD could not be loaded ({0})"
				);
		propertyAccessor.setProperty(
				"xmode-error.termchar-invalid",
				"The value of the AT_CHAR attribute is invalid ({0})"
				);
		propertyAccessor.setProperty(
				"xmode-error.doctype-invalid",
				"Expected a document type of MODE, found {0}"
				);
		propertyAccessor.setProperty(
				"xmode-error.empty-tag",
				"The {0} tag cannot be empty"
				);
		propertyAccessor.setProperty(
				"xmode-error.token-invalid",
				"The token type {0} is invalid"
				);
		propertyAccessor.setProperty(
				"xmode-error.empty-keyword",
				"The keyword text cannot be empty"
				);
		//}}}
	}


	private static FilePropertyAccessor propertyAccessor = new FilePropertyAccessor();//}}}
}

