/*
 *  HtmlDocument.java
 *  Copyright (c) 2002 Andre Kaplan
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package code2html.html;

import java.io.IOException;
import java.io.Writer;

import org.gjt.sp.jedit.syntax.SyntaxStyle;


/**
 *  Description of the Class
 *
 *@author     lars
 *@created    March 31, 2003
 */
public class HtmlDocument {

	/**
	 *  Constructor for the HtmlDocument object
	 *
	 *@param  viewBgColor    Description of the Parameter
	 *@param  viewFgColor    Description of the Parameter
	 *@param  syntaxStyles   Description of the Parameter
	 *@param  style          Description of the Parameter
	 *@param  gutter         Description of the Parameter
	 *@param  title          Description of the Parameter
	 *@param  lineSeparator  Description of the Parameter
	 */
	public HtmlDocument(
			String viewBgColor,
			String viewFgColor,
			SyntaxStyle[] syntaxStyles,
			HtmlStyle style,
			HtmlGutter gutter,
			String title,
			String lineSeparator
			) {
		this.viewBgColor = viewBgColor;
		this.viewFgColor = viewFgColor;
		this.syntaxStyles = syntaxStyles;
		this.style = style;
		this.gutter = gutter;
		this.title = title;
		this.lineSeparator = lineSeparator;
	}


	/**
	 *  Description of the Method
	 *
	 *@param  out              Description of the Parameter
	 *@exception  IOException  Description of the Exception
	 */
	public void htmlClose(Writer out)
			 throws IOException {
		if (style instanceof HtmlCssStyle) {
			out.write("</span>");
			out.write("</pre>");
		} else {
			out.write("</fo:block>");
		}
		out.write(this.lineSeparator);
	}


	/**
	 *  Description of the Method
	 *
	 *@param  out              Description of the Parameter
	 *@exception  IOException  Description of the Exception
	 */
	public void htmlOpen(Writer out)
			 throws IOException {
		if (style instanceof HtmlCssStyle) {
			out.write("<pre>");
			out.write("<span class=\"syntax0\">");
		} else {
			out.write("<fo:block xmlns:fo=\"http://www.w3.org/1999/XSL/Format\" color=\"");
			out.write(this.viewFgColor);
			out.write("\">");
		}
	}


	private HtmlGutter gutter;
	private String lineSeparator;

	private HtmlStyle style;

	private SyntaxStyle[] syntaxStyles;

	private String title;
	private String viewBgColor;
	private String viewFgColor;
}

