<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        version="1.0">

    <xsl:output method="html"/>
<!-- 

    <xsl:param name="profile.security" select="'auth;teacher;author'"/>
    <xsl:param name="profile.os" select="'tasks'"/>
    <xsl:param name="profile.arch" select="'html'"/>
    <xsl:param name="profile.userlevel" select="'standard'"/>
    <xsl:param name="profile.condition" select="'normal'"/>
    <xsl:param name="profile.separator" select="';'"/>
 -->
    <xsl:param name="el.icon.base" select="'file:///c:/devel/docbook-custom/images/el/'"/>
    <xsl:param name="el.icon.ext" select="'.png'"/>

    <!-- security: docs are accessible only for auth, students... -->
    <xsl:param name="el.security.caption" select="'security'"/>
    <xsl:param name="el.security.levels" select="'noauth;auth;student;teacher;author'"/>
    <xsl:param name="el.security.level.empty" select="'auth'"/>

    <!-- os: from docs, just something is presented: tasks, discussions, lectures, practices, tests... -->
    <xsl:param name="el.os.caption" select="'os'"/>
    <xsl:param name="el.os.levels" select="'all;task;discussion;lecture;practice;test;link;video'"/>
    <xsl:param name="el.os.level.empty" select="'all'"/>

    <!-- arch: docs are presented for the specified arch: html (chunks), slides, printable (all in 1), pda, wml -->
    <xsl:param name="el.arch.caption" select="'arch'"/>
    <xsl:param name="el.arch.levels" select="'html;printable;pda;wml;slides'"/>
    <xsl:param name="el.arch.level.empty" select="'html'"/>

    <!-- userlevel (richness of content): less standard more-->
    <xsl:param name="el.userlevel.caption" select="'userlevel'"/>
    <xsl:param name="el.userlevel.levels" select="'less;standard;more'"/>
    <xsl:param name="el.userlevel.level.empty" select="'standard'"/>

    <!-- speed of going thru: slow normal fast -->
    <xsl:param name="el.condition.caption" select="'speed'"/>
    <xsl:param name="el.condition.levels" select="'slow;normal;fast'"/>
    <xsl:param name="el.condition.level.empty" select="'normal'"/>

    <!--
    <xsl:template match="/book">
        <html>
            <body>
                <xsl:call-template name="user.header.navigation">
                    <xsl:with-param name="node" select="."/>
                 </xsl:call-template>
            </body>
        </html>
    </xsl:template>        
-->
<!-- Returns non-empty string if list in $b contains one ore more values from list $a -->

    <xsl:template name="cross.compare">
        <xsl:param name="a"/>
        <xsl:param name="b"/>
        <xsl:param name="sep" select="$profile.separator"/>
        <xsl:variable name="head" select="substring-before(concat($a, $sep), $sep)"/>
        <xsl:variable name="tail" select="substring-after($a, $sep)"/>
        <xsl:if test="contains(concat($sep, $b, $sep), concat($sep, $head, $sep))">
            <xsl:value-of select="concat($head, $sep)"/>
        </xsl:if>
        <xsl:if test="$tail">
            <xsl:call-template name="cross.compare">
                <xsl:with-param name="a" select="$tail"/>
                <xsl:with-param name="b" select="$b"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template match="*" mode="el-security-links">
        <!-- creates the link to other securities -->
        <xsl:param name="profile.security" select="$profile.security"/>
        <xsl:variable name="el.security.levels">
            <xsl:choose>
                <xsl:when test="@security">
                    <xsl:value-of select="@security"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$el.security.levels"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <table border="1">
            <tr>
                <th colspan="5">
                    <xsl:call-template name="gentext">
                        <xsl:with-param name="key">el.security</xsl:with-param>
                    </xsl:call-template>
                </th>
            </tr>
            <tr>
                <xsl:call-template name="el-security-link">
                    <xsl:with-param name="el.security.levels" select="$el.security.levels"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="el-security-link">
        <!-- creates the link to one security -->
        <xsl:param name="el.security.levels"/>
        <xsl:if test="$el.security.levels != ''">
            <xsl:variable name="el.security.level">
                <xsl:choose>
                    <xsl:when test="contains($el.security.levels,';')">
                        <xsl:value-of select="substring-before($el.security.levels, $profile.separator)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$el.security.levels"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:variable name="href">
                <xsl:call-template name="profile-base-dir">
                    <xsl:with-param name="profile.security" select="$el.security.level"/>
                </xsl:call-template>
            </xsl:variable>

            <td align="center">
                <xsl:if test="$el.security.level = $profile.security">
                <!-- mark current security -->
                    <xsl:attribute name="style">background-color: blue</xsl:attribute>
                </xsl:if>
                <a href="{$href}">
                    <img align="absmiddle" border="0">
                        <xsl:attribute name="alt">
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="concat('el.security.', $el.security.level)"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="src">
                            <xsl:call-template name="el-icon-url">
                                <xsl:with-param name="profile.attribute" select="'security'"/>
                                <xsl:with-param name="profile.value" select="$el.security.level"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </img>
                </a>
            </td>
            <xsl:call-template name="el-security-link">
                <xsl:with-param name="el.security.levels" select="substring-after($el.security.levels, $profile.separator)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template match="*" mode="el-os-links">
        <!-- creates the link to other securities -->
        <xsl:param name="profile.os" select="$profile.os"/>
        <xsl:variable name="el.os.levels">
            <xsl:choose>
                <xsl:when test="@os">
                    <xsl:value-of select="@os"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$el.os.levels"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <table border="1">
            <tr>
                <th colspan="5">
                    <xsl:call-template name="gentext">
                        <xsl:with-param name="key">el.os</xsl:with-param>
                    </xsl:call-template>
                </th>
            </tr>
            <tr>
                <xsl:call-template name="el-os-link">
                    <xsl:with-param name="el.os.levels" select="$el.os.levels"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="el-os-link">
        <!-- creates the link to one os -->
        <xsl:param name="el.os.levels"/>
        <xsl:if test="$el.os.levels != ''">
            <xsl:variable name="el.os.level">
                <xsl:choose>
                    <xsl:when test="contains($el.os.levels,';')">
                        <xsl:value-of select="substring-before($el.os.levels, $profile.separator)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$el.os.levels"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:variable name="href">
                <xsl:call-template name="profile-base-dir">
                    <xsl:with-param name="profile.os" select="$el.os.level"/>
                </xsl:call-template>
            </xsl:variable>

            <td align="center">
                <xsl:if test="$el.os.level = $profile.os">
                <!-- mark current os -->
                    <xsl:attribute name="style">background-color: blue</xsl:attribute>
                </xsl:if>
                <a href="{$href}">
                    <img align="absmiddle" border="0">
                        <xsl:attribute name="alt">
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="concat('el.os.', $el.os.level)"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="src">
                            <xsl:call-template name="el-icon-url">
                                <xsl:with-param name="profile.attribute" select="'os'"/>
                                <xsl:with-param name="profile.value" select="$el.os.level"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </img>
                </a>
            </td>
            <xsl:call-template name="el-os-link">
                <xsl:with-param name="el.os.levels" select="substring-after($el.os.levels, $profile.separator)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="*" mode="el-arch-links">
        <!-- creates the link to other securities -->
        <xsl:param name="profile.arch" select="$profile.arch"/>
        <xsl:variable name="el.arch.levels">
            <xsl:choose>
                <xsl:when test="@arch">
                    <xsl:value-of select="@arch"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$el.arch.levels"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <table border="1">
            <tr>
                <th colspan="5">
                    <xsl:call-template name="gentext">
                        <xsl:with-param name="key">el.arch</xsl:with-param>
                    </xsl:call-template>
                </th>
            </tr>
            <tr>
                <xsl:call-template name="el-arch-link">
                    <xsl:with-param name="el.arch.levels" select="$el.arch.levels"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="el-arch-link">
        <!-- creates the link to one arch -->
        <xsl:param name="el.arch.levels"/>
        <xsl:if test="$el.arch.levels != ''">
            <xsl:variable name="el.arch.level">
                <xsl:choose>
                    <xsl:when test="contains($el.arch.levels,';')">
                        <xsl:value-of select="substring-before($el.arch.levels, $profile.separator)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$el.arch.levels"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:variable name="href">
                <xsl:call-template name="profile-base-dir">
                    <xsl:with-param name="profile.arch" select="$el.arch.level"/>
                </xsl:call-template>
            </xsl:variable>

            <td align="center">
                <xsl:if test="$el.arch.level = $profile.arch">
                <!-- mark current arch -->
                    <xsl:attribute name="style">background-color: blue</xsl:attribute>
                </xsl:if>
                <a href="{$href}">
                    <img align="absmiddle" border="0">
                        <xsl:attribute name="alt">
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="concat('el.arch.', $el.arch.level)"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="src">
                            <xsl:call-template name="el-icon-url">
                                <xsl:with-param name="profile.attribute" select="'arch'"/>
                                <xsl:with-param name="profile.value" select="$el.arch.level"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </img>
                </a>
            </td>
            <xsl:call-template name="el-arch-link">
                <xsl:with-param name="el.arch.levels" select="substring-after($el.arch.levels, $profile.separator)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="*" mode="el-userlevel-links">
        <!-- creates the link to other securities -->
        <xsl:param name="profile.userlevel" select="$profile.userlevel"/>
        <xsl:variable name="el.userlevel.levels">
            <xsl:choose>
                <xsl:when test="@userlevel">
                    <xsl:value-of select="@userlevel"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$el.userlevel.levels"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <table border="1">
            <tr>
                <th colspan="5">
                    <xsl:call-template name="gentext">
                        <xsl:with-param name="key">el.userlevel</xsl:with-param>
                    </xsl:call-template>
                </th>
            </tr>
            <tr>
                <xsl:call-template name="el-userlevel-link">
                    <xsl:with-param name="el.userlevel.levels" select="$el.userlevel.levels"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="el-userlevel-link">
        <!-- creates the link to one userlevel -->
        <xsl:param name="el.userlevel.levels"/>
        <xsl:if test="$el.userlevel.levels != ''">
            <xsl:variable name="el.userlevel.level">
                <xsl:choose>
                    <xsl:when test="contains($el.userlevel.levels,';')">
                        <xsl:value-of select="substring-before($el.userlevel.levels, $profile.separator)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$el.userlevel.levels"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:variable name="href">
                <xsl:call-template name="profile-base-dir">
                    <xsl:with-param name="profile.userlevel" select="$el.userlevel.level"/>
                </xsl:call-template>
            </xsl:variable>

            <td align="center">
                <xsl:if test="$el.userlevel.level = $profile.userlevel">
                <!-- mark current userlevel -->
                    <xsl:attribute name="style">background-color: blue</xsl:attribute>
                </xsl:if>
                <a href="{$href}">
                    <img align="absmiddle" border="0">
                        <xsl:attribute name="alt">
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="concat('el.userlevel.', $el.userlevel.level)"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="src">
                            <xsl:call-template name="el-icon-url">
                                <xsl:with-param name="profile.attribute" select="'userlevel'"/>
                                <xsl:with-param name="profile.value" select="$el.userlevel.level"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </img>
                </a>
            </td>
            <xsl:call-template name="el-userlevel-link">
                <xsl:with-param name="el.userlevel.levels" select="substring-after($el.userlevel.levels, $profile.separator)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="*" mode="el-condition-links">
        <!-- creates the link to other securities -->
        <xsl:param name="profile.condition" select="$profile.condition"/>
        <xsl:variable name="el.condition.levels">
            <xsl:choose>
                <xsl:when test="@condition">
                    <xsl:value-of select="@condition"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$el.condition.levels"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <table border="1">
            <tr>
                <th colspan="5">
                    <xsl:call-template name="gentext">
                        <xsl:with-param name="key">el.condition</xsl:with-param>
                    </xsl:call-template>
                </th>
            </tr>
            <tr>
                <xsl:call-template name="el-condition-link">
                    <xsl:with-param name="el.condition.levels" select="$el.condition.levels"/>
                </xsl:call-template>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="el-condition-link">
        <!-- creates the link to one condition -->
        <xsl:param name="el.condition.levels"/>
        <xsl:if test="$el.condition.levels != ''">
            <xsl:variable name="el.condition.level">
                <xsl:choose>
                    <xsl:when test="contains($el.condition.levels,';')">
                        <xsl:value-of select="substring-before($el.condition.levels, $profile.separator)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$el.condition.levels"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:variable name="href">
                <xsl:call-template name="profile-base-dir">
                    <xsl:with-param name="profile.condition" select="$el.condition.level"/>
                </xsl:call-template>
            </xsl:variable>

            <td align="center">
                <xsl:if test="$el.condition.level = $profile.condition">
                <!-- mark current condition -->
                    <xsl:attribute name="style">background-color: blue</xsl:attribute>
                </xsl:if>
                <a href="{$href}">
                    <img align="absmiddle" border="0">
                        <xsl:attribute name="alt">
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="concat('el.condition.', $el.condition.level)"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="src">
                            <xsl:call-template name="el-icon-url">
                                <xsl:with-param name="profile.attribute" select="'condition'"/>
                                <xsl:with-param name="profile.value" select="$el.condition.level"/>
                            </xsl:call-template>
                        </xsl:attribute>
                    </img>
                </a>
            </td>
            <xsl:call-template name="el-condition-link">
                <xsl:with-param name="el.condition.levels" select="substring-after($el.condition.levels, $profile.separator)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="el-icon-url">
        <!-- computes the e-l icon file name -->
        <xsl:param name="profile.attribute"/>
        <xsl:param name="profile.value"/>
        <xsl:variable name="default">
            <xsl:choose>
                <xsl:when test="$profile.attribute='security'">
                    <xsl:value-of select="$el.security.level.empty"/>
                </xsl:when>
                <xsl:when test="$profile.attribute='os'">
                    <xsl:value-of select="$el.os.level.empty"/>
                </xsl:when>
                <xsl:when test="$profile.attribute='arch'">
                    <xsl:value-of select="$el.arch.level.empty"/>
                </xsl:when>
                <xsl:when test="$profile.attribute='userlevel'">
                    <xsl:value-of select="$el.userlevel.level.empty"/>
                </xsl:when>
                <xsl:when test="$profile.attribute='condition'">
                    <xsl:value-of select="$el.condition.level.empty"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="value">
            <xsl:choose>
                <xsl:when test="$profile.value=''">
                    <xsl:value-of select="$default"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$profile.value"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="concat($el.icon.base, $profile.attribute, '-', $value, $el.icon.ext)"/>
    </xsl:template>

    <xsl:template name="profile-base-dir">
        <!-- computes the base dir for the given profile -->
        <xsl:param name="profile.security" select="$profile.security"/>
        <xsl:param name="profile.os" select="$profile.os"/>
        <xsl:param name="profile.arch" select="$profile.arch"/>
        <xsl:param name="profile.userlevel" select="$profile.userlevel"/>
        <xsl:param name="profile.condition" select="$profile.condition"/>
        <xsl:variable name="path.security">
            <xsl:choose>
                <xsl:when test="$profile.security = ''">
                    <xsl:value-of select="''"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat($profile.security, '/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="path.os">
            <xsl:choose>
                <xsl:when test="$profile.os = ''">
                    <xsl:value-of select="''"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat($profile.os, '/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="path.arch">
            <xsl:choose>
                <xsl:when test="$profile.arch = ''">
                    <xsl:value-of select="''"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat($profile.arch, '/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="path.userlevel">
            <xsl:choose>
                <xsl:when test="$profile.userlevel = ''">
                    <xsl:value-of select="''"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat($profile.userlevel, '/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="path.condition">
            <xsl:choose>
                <xsl:when test="$profile.condition = ''">
                    <xsl:value-of select="''"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat($profile.condition, '/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="concat($path.security, $path.os, $path.arch, $path.userlevel, $path.condition)"/>

    </xsl:template>
</xsl:stylesheet>