<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns="http://www.w3.org/TR/xhtml1/transitional" xmlns:jedit="java:code2html.Main" exclude-result-prefixes="jedit #default">
    <xsl:import href="http://docbook.sourceforge.net/release/xsl/current/html/docbook.xsl"/>
    <xsl:param name="linenumbering.extension" select="0"/>
    <xsl:param name="codehighlighting.extension" select="1"/>
    <xsl:param name="use.extensions" select="1"/>
    <xsl:param name="event" select="'HPI, Seminar Systemmodellierung SS2003'" />
    <xsl:param name="altlogo" select="'Hasso-Plattner-Institut'"/>
    
    <xsl:template match="programlisting">
        <pre class="programlisting" onclick="makeScroll(this)">
            <xsl:apply-templates/>
        </pre>
    </xsl:template>
    
    <xsl:template match="/">
            <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="/slides">
        <html>
            <head>
                <title>
                    <xsl:value-of select="./slidesinfo/title"/>
                </title>
                <script type="text/javascript" src="resources/slides.js"></script>
<!--                <xsl:element name="link">
                    <xsl:attribute name="rel">stylesheet</xsl:attribute>
                    <xsl:attribute name="type">text/css</xsl:attribute>
                    <xsl:attribute name="href">resources/slides.css</xsl:attribute>
                    <xsl:attribute name="media">screen</xsl:attribute>
                </xsl:element>
                <xsl:element name="link">
                    <xsl:attribute name="rel">stylesheet</xsl:attribute>
                    <xsl:attribute name="type">text/css</xsl:attribute>
                    <xsl:attribute name="href">resources/slides-print.css</xsl:attribute>
                    <xsl:attribute name="media">print</xsl:attribute>
                </xsl:element> -->
                <link rel="stylesheet" type="text/css" href="resources/slides.css" media="screen" />
                <link rel="stylesheet" type="text/css" href="resources/slides-print.css" media="print" />
            </head>
            <body onload="init()">
                <div class="slidetitle">
                    <xsl:call-template name="navigation"/>
                    <xsl:apply-templates select="//slidesinfo/title"/>
                    <xsl:apply-templates select="//slidesinfo/subtitle"/>
                    <div id="authors">
                        <xsl:apply-templates select="//slidesinfo/authorgroup|//slidesinfo/author"/>
                    </div>
                    <div id="biglogo">
                        <img src="resources/biglogo.png">
				<xsl:attribute name="alt">
					<xsl:value-of select="altlogo" />
				</xsl:attribute>
			</img>
                    </div>
                </div>
                <xsl:apply-templates select="foil|foilgroup"/>
                <xsl:call-template name="toc"/>
            </body>
        </html>
    </xsl:template>
	
    <xsl:template match="firstname|surname">
        <xsl:apply-templates/>
        <xsl:text> </xsl:text>
    </xsl:template>
	
    <xsl:template match="//slidesinfo/subtitle">
        <h2 class="subtitle">
            <xsl:apply-templates/>
        </h2>
    </xsl:template>
	
    <xsl:template match="//slidesinfo/title">
        <h1>
            <xsl:apply-templates/>
        </h1>
    </xsl:template>
	
    <xsl:template match="authorgroup">
        <xsl:for-each select="author">
            <div class="author">
                <xsl:apply-templates/>
            </div>
        </xsl:for-each>
    </xsl:template>
	
    <xsl:template name="toc">
        <div id="slidetoc">
            <h4>table of contents</h4>
            <a href="#" onclick="jumptoc(0)">
                <xsl:value-of select="//title"/>
            </a>
            <xsl:variable name="num">1</xsl:variable>
            <ol>
                <xsl:for-each select="foil|foilgroup">
                    <li>
                        <a href="#">
                            <xsl:attribute name="onclick">
                                <xsl:text>jumptoc(</xsl:text>
                                <xsl:number level="any" count="foil|foilgroup"/>
                                <xsl:text>)</xsl:text>
                            </xsl:attribute>
                            <xsl:value-of select="title"/>
                        </a>
                        <xsl:if test="name()='foilgroup'">
                            <ol>
                                <xsl:for-each select="foil">
                                    <li>
                                        <a href="#">
                                            <xsl:attribute name="onclick">
                                                <xsl:text>jumptoc(</xsl:text>
                                                <xsl:number level="any" count="foil|foilgroup"/>
                                                <xsl:text>)</xsl:text>
                                            </xsl:attribute>
                                            <xsl:value-of select="title"/>
                                        </a>
                                    </li>
                                </xsl:for-each>
                            </ol>
                        </xsl:if>
                    </li>
                </xsl:for-each>
            </ol>
        </div>
    </xsl:template>
	
    <xsl:template match="foilgroup">
        <xsl:call-template name="anchor">
            <xsl:with-param name="conditional" select="0"/>
        </xsl:call-template>
        <div class="slidegroup">
            <table class="foil" cellspacing="0" cellpadding="0" border="0">
                <tr>
                    <th class="foil" colspan="2">
                        <xsl:apply-templates select="title" mode="show"/>
                    </th>
                </tr>
                <tr>
                    <td class="foil" colspan="2">
                        <xsl:apply-templates select="*[name()!='foil']"/>
                        <ul>
                            <xsl:for-each select="preceding-sibling::foilgroup">
                                <li class="previous">
                                    <xsl:apply-templates select="title" mode="show"/>
                                </li>
                            </xsl:for-each>
                            <li>
                                <xsl:apply-templates select="title" mode="show"/>
                                <ul>
                                    <xsl:for-each select="foil">
                                        <li>
                                            <xsl:apply-templates select="title" mode="show"/>
                                        </li>
                                    </xsl:for-each>
                                </ul>
                            </li>
                            <xsl:for-each select="following-sibling::foilgroup">
                                <li class="following">
                                    <xsl:apply-templates select="title" mode="show"/>
                                </li>
                            </xsl:for-each>
                        </ul>
                    </td>
                </tr>
                <tr>
                    <td class="footer">
                        <xsl:call-template name="footer"/>
                    </td>
                    <td class="logo">
                        <xsl:call-template name="logo"/>
                    </td>
                </tr>
            </table>
        </div>
		<!--
		<div class="slidegroup">
			<xsl:call-template name="navigation" />
			<xsl:apply-templates select="*[name()!='foil']"/>
			<xsl:call-template name="footer" />
		</div>
		-->
        <xsl:apply-templates select="foil"/>
    </xsl:template>
	
    <xsl:template match="foil">
        <xsl:call-template name="anchor">
            <xsl:with-param name="conditional" select="0"/>
        </xsl:call-template>
        <div class="slide">
            <table class="foil" cellspacing="0" cellpadding="0" border="0">
                <tr>
                    <th class="foil" colspan="2">
                        <xsl:apply-templates select="title" mode="show"/>
                    </th>
                </tr>
                <tr>
                    <td class="foil" colspan="2">
                        <xsl:apply-templates/>
                    </td>
                </tr>
                <tr>
                    <td class="footer">
                        <xsl:call-template name="footer"/>
                    </td>
                    <td class="logo">
                        <xsl:call-template name="logo"/>
                    </td>
                </tr>
            </table>
        </div>
    </xsl:template>
	
    <xsl:template match="speakernotes"></xsl:template>
	
    <xsl:template match="foilinfo"></xsl:template>
	
    <xsl:template match="foil/title"></xsl:template>
	
    <xsl:template match="foilgroup/title"></xsl:template>
	
    <xsl:template match="foilgroup/title" mode="show">
        <xsl:apply-templates/>
    </xsl:template>
	
    <xsl:template match="foil/title" mode="show">
        <xsl:apply-templates/>
    </xsl:template>
	
    <xsl:template name="navigation">
        <div class="navigation">
            <a href="#" onclick="gohome(this)">
                <img src="plain/active/nav-home.png" alt="home" onmouseover="activate(this)" onmouseout="deactivate(this)"/>
            </a>
            <a href="#" onclick="gotoc(this)">
                <img src="plain/active/nav-toc.png" alt="Table of contents" onmouseover="activate(this)" onmouseout="deactivate(this)"/>
            </a>
            <a href="#" onclick="prev(this)">
                <img src="plain/active/nav-prev.png" alt="previous slide" onmouseover="activate(this)" onmouseout="deactivate(this)"/>
            </a>
            <a href="#" onclick="goup(this)">
                <img src="plain/active/nav-up.png" alt="previous slide" onmouseover="activate(this)" onmouseout="deactivate(this)"/>
            </a>
            <a href="#" onclick="next(this)">
                <img src="plain/active/nav-next.png" alt="next slide" onmouseover="activate(this)" onmouseout="deactivate(this)"/>
            </a>
        </div>
    </xsl:template>
	
    <xsl:template name="footer">
			<xsl:value-of select="$event" /><xsl:text> </xsl:text><xsl:value-of select="/slides/slidesinfo/title"/> / 
			<span class="index">
            <xsl:value-of select="count(preceding::foil)+ count(preceding::foilgroup)+ count(ancestor::foilgroup)+ 1"/>
        </span>
    </xsl:template>
	
    <xsl:template name="logo">
        <img src="resources/smalllogo.png">
		<xsl:attribute name="alt">
			<xsl:value-of select="$altlogo" />
		</xsl:attribute>
	</img>
    </xsl:template>
	
    <xsl:template match="mediaobject[@role='float']">
        <!--<xsl:message>Floating MediaObject.</xsl:message>-->
        <div class="floatingmedia">
            <xsl:apply-templates/>
        </div>
    </xsl:template>
    
</xsl:stylesheet>

