<?xml version="1.0" encoding="Windows-1250"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:f="http://tomp.sf.net/2004/flatten"
        xmlns:du="java:DateUtil"
        xmlns:prof="http://tomp.sf.net/2004/profile" 
        xmlns:rr="http://tomp.sf.net/2004/resource/reference"
        exclude-result-prefixes="du f rr prof"
        version="1.0">

    <xsl:import href="../calendar.xsl"/>
    <xsl:strip-space elements="*" />

    <xsl:param name="slides-all.xml" select="'file:///c:/devel/hybrid/build/web/pb138/slides-all.xml'"/>
    <xsl:param name="base" select="'/c:/devel/hybrid/src/pb138/'"/>
    <xsl:param name="dest-dir" select="'c:/devel/hybrid/build/web/pb138/'"/>

    <xsl:param name="path-to-base" select="''"/>
    <xsl:param name="at-subject-root" select="0"/>
    <xsl:param name="show-navig-bar-vert" select="1"/>
    <xsl:param name="show-navig-bar-horiz" select="1"/>
    <xsl:param name="modules-pane" select="'1std-terminology/ 5transformation/'"/>

    <xsl:param name="config">
        <navig-item>
            <show item="discussion" as="link"/>
            <show item="module" as="link"/>
            <show item="task" as="link"/>
            <show item="links" as="link"/>
            <show item="schedule" as="link"/>
            <show item="glossary" as="link"/>
            <show item="test" as="link"/>
        </navig-item>
	<!--
	<modules pane="1std-terminology/ 5transformation/" />
	<modules navig="1std-terminology/ 5transformation/" />-->
        <!--<navig-item>
            <show item="discussion" as=""/>
            <show item="module" as=""/>
            <show item="task" as=""/>
            <show item="links" as=""/>
            <show item="schedule" as=""/>
            <show item="glossary" as=""/>
            <show item="test" as=""/>
        </navig-item>-->
        <pane-item>
            <show item="discussion" as="full"/>
            <show item="module" as="full"/>
            <show item="task" as="full"/>
            <show item="links" as="full"/>
            <show item="schedule" as="full"/>
            <show item="glossary" as="full"/>
            <show item="test" as="full"/>
        </pane-item>
    </xsl:param>

    <xsl:template match="subject">
    	<xsl:message>$modules-pane=<xsl:value-of select="$modules-pane"/></xsl:message>
    	<xsl:message>$path-to-base=<xsl:value-of select="$path-to-base"/></xsl:message>
    	<xsl:message>$navig-vert=<xsl:value-of select="$show-navig-bar-vert"/></xsl:message>
        <mainpage>
            <xsl:apply-templates select="title" mode="mainpage"/>
	    <xsl:choose>
	    <xsl:when test="$show-navig-bar-vert=1">
		    <xsl:apply-templates select="highlights" mode="mainpage"/>
		    <navig-bar-vert>
			<xsl:apply-templates select="module |discussion |schedule |task |test |glossary" mode="navig-item"/>
		    </navig-bar-vert>
	    </xsl:when>
	    <xsl:otherwise>
	    	<link ref="../mainpage.html"/>
	    </xsl:otherwise>
	    </xsl:choose>
            <main-pane>
                <xsl:apply-templates select="module[contains(concat($modules-pane, ' '), concat(@f:src-dir-rel, ' '))] |discussion |schedule |task |test |links |glossary" mode="pane-item"/>
            </main-pane>
            <xsl:if test="$show-navig-bar-horiz=1">
		<navig-bar-horiz>
		    <xsl:apply-templates select="links" mode="navig-item"/>
		</navig-bar-horiz>
	    </xsl:if>
            <footer>
                <xsl:apply-templates select="author"/>
            </footer>
        </mainpage>
    </xsl:template>

    <xsl:template match="highlights|title" mode="mainpage">
        <xsl:copy-of select="."/>
    </xsl:template>

    <xsl:template match="*" mode="navig-item">
        <xsl:variable name="this-local-name" select="local-name()"/>
        <navig-item type="{local-name()}">
	    <xsl:copy-of select="@f:path-to-base"/>
            <link ref="{concat($path-to-base, @f:src-dir-rel, 'mainpage.html')}"/>
	    <xsl:choose>
		<xsl:when test="$config/navig-item/show[@item=$this-local-name]/@as='link'">
		    <xsl:apply-templates select="." mode="link"/>
		</xsl:when>
		<xsl:when test="$config/navig-item/show[@item=$this-local-name]/@as='full'">
		    <xsl:apply-templates select="." mode="full"/>
		</xsl:when>
	    </xsl:choose>
        </navig-item>
    </xsl:template>

    <xsl:template match="*" mode="pane-item">
        <xsl:variable name="this-local-name" select="local-name()"/>
        <pane-item type="{local-name()}">
            <xsl:copy-of select="@created|@author|@id|@f:path-to-base"/>
	    <xsl:choose>
	    	<xsl:when test="$show-navig-bar-vert=1 and $at-subject-root=1">
			<link ref="{concat($path-to-base, @f:src-dir-rel, 'index.html')}"/>
		</xsl:when>
	    	<xsl:when test="$show-navig-bar-vert=1">
			<link ref="{concat(@f:path-to-base, @f:src-dir-rel, 'index.html')}"/>
		</xsl:when>
		<xsl:otherwise>
			<link ref="{concat($path-to-base, @f:src-dir-rel, 'mainpage.html')}"/>
		</xsl:otherwise>
	    </xsl:choose>
	    <xsl:choose>
		<xsl:when test="$config/pane-item/show[@item=$this-local-name]/@as='link'">
		    <!--  <xsl:message>LINK *** <xsl:value-of select="$this-local-name"/></xsl:message>-->
		    <xsl:apply-templates select="." mode="link"/>
		</xsl:when>
		<xsl:when test="$config/pane-item/show[@item=$this-local-name]/@as='full'">
		    <!-- <xsl:message>FULL *** <xsl:value-of select="$this-local-name"/></xsl:message>-->
		    <xsl:apply-templates select="." mode="full"/>
		</xsl:when>
	    </xsl:choose>
        </pane-item>
    </xsl:template>

<!-- MODULE -->
    <xsl:template match="module" mode="link">
        <xsl:copy-of select="title"/>
        <xsl:copy-of select="highlights"/>
	<!-- 
        <icon>
            <img src="{$path-to-base}../../../system/icons/48x48/filesystems/folder_orange.png" align="top"/>
        </icon>
	 -->
    </xsl:template>
<!-- 
    <xsl:template match="module" mode="full">
        <xsl:copy-of select="title"/>
        <xsl:copy-of select="highlights"/>
        <body>
            <xsl:apply-templates mode="body-item"/>
        </body>
    </xsl:template>
 -->
    <xsl:template match="*" mode="full" priority="-1">
        <xsl:copy>
    	    <xsl:copy-of select="@*"/>
	    <xsl:apply-templates mode="full"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="*" mode="link" priority="-1">
    </xsl:template>

    <xsl:template match="*" mode="body-item" priority="-1">
        <body-item type="{local-name()}">
            <xsl:copy-of select="@created|@author|@id|@f:path-to-base"/>
	        <xsl:apply-templates select="." mode="full"/>
        </body-item>
    </xsl:template>

    <xsl:template match="title|highlights" mode="link"/>
    <xsl:template match="title|highlights" mode="full"/>
    <xsl:template match="title|highlights" mode="body-item"/>

    <xsl:template match="module|lecture|practices|slides" mode="full">
    	<xsl:if test="@date">
		<xsl:call-template name="make-weekly-calendar">
			    <xsl:with-param name="date" select="@date"/>
		</xsl:call-template>
	</xsl:if>
	    <xsl:copy-of select="title"/>
	    <xsl:copy-of select="highlights"/>
	    <xsl:if test="@href">
		    <link ref="{concat($path-to-base, @f:src-dir-rel, substring-before(@href, '.xml'), '/index.html')}"/>
	    </xsl:if>
	    <xsl:if test="*">
	    	<body>
		        <xsl:apply-templates mode="body-item"/>
		</body>
	    </xsl:if>
    </xsl:template>

    <xsl:template match="task|discussion|test|glossary|links" mode="full">
	    <xsl:copy-of select="title"/>
	    <xsl:copy-of select="highlights"/>
	    <xsl:if test="@href">
		    <link ref="{concat($path-to-base, @f:src-dir-rel, substring-before(@href, '.xml'), '/index.html')}"/>
	    </xsl:if>
	    <xsl:if test="*">
	    	<body>
		    <xsl:apply-templates mode="body-item"/>
                </body>
	    </xsl:if>
    </xsl:template>

    <xsl:template match="qandaset|qandadiv|glossdiv" mode="body-item">
            <xsl:apply-templates mode="body-item"/>
    </xsl:template>

    <xsl:template match="qandaentry|glossentry" mode="body-item">
        <body-item type="{local-name()}">
            <xsl:copy-of select="@created|@author"/>
            <title><xsl:apply-templates select="question|glossterm" mode="full"/></title>
            <body><xsl:apply-templates select="answer|glossdef" mode="full"/></body>
        </body-item>
    </xsl:template>

    <xsl:template match="question|glossterm" mode="full">
            <xsl:apply-templates mode="full"/>
    </xsl:template>

    <xsl:template match="answer|glossdef" mode="full">
        <body-item type="{local-name()}">
            <xsl:apply-templates mode="full"/>
        </body-item>
    </xsl:template>
</xsl:stylesheet>