<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:p="http://www.obqo.de/presentation"
  xmlns:html="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="p html">

  <xsl:output method="html" />

  <xsl:param name="page" select="floor(1 div count(/*/p:slide))" />
  <!-- 1 is mapped to 1, everything greater than 1 is mapped to 0 -->
  <xsl:param name="subpage" select="0" />
  <xsl:param name="last" />
  <xsl:param name="mode" select="'online'" />
  <xsl:param name="res" select="/*/p:styles/@init" />

  <xsl:variable name="imgdir" select="'icons/'" />
  <xsl:variable name="cssdir" select="'css/'" />
  <xsl:variable name="scriptdir" />
  <xsl:variable name="home" select="'index.html'" />

  <xsl:variable name="step" select="10" />

  <xsl:preserve-space elements="*" />

  <!-- language support -->
  <p:i18n lang="de">
    <toc>Inhaltsverzeichnis</toc>
    <page>Seite</page>
    <script>Skript</script>
    <backto>Zurck zur</backto>
    <prev>Vorherige</prev>
    <next>Nchste</next>
    <home>Startseite</home>
    <cont>Weiter</cont>
  </p:i18n>
  <p:i18n lang="en"> <!-- Last one is the default if the specified language 
                          is not available. That means: new languages should
                          be added *before* this entry. -->
    <toc>Table of Contents</toc>
    <page>Page</page>
    <script>Script</script>
    <backto>Back to</backto>
    <prev>Previous</prev>
    <next>Next</next>
    <home>Home</home>
    <cont>Continue</cont>
  </p:i18n>

  <xsl:variable name="upper">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
  <xsl:variable name="lower">abcdefghijklmnopqrstuvwxyz</xsl:variable>
  <xsl:variable name="i18n" 
       select="document('')/*/p:i18n[
               @lang = translate(substring-before(
                                    concat(current()/*/@xml:lang,'-'),'-'),
                                 $upper,
                                 $lower) 
               or position()=last()]" />   <!-- default language -->



  <!-- root element -->
  <xsl:template match="p:presentation">
    <html>
      <head>
        <meta http-equiv="Pragma" content="no-cache" />
        <meta http-equiv="Expires" content="-1" />
        <link rel="stylesheet" type="text/css" href="{$cssdir}{$mode}.css" />
        <link rel="stylesheet" type="text/css" href="{$cssdir}tree-view.css" />
        <xsl:if test="$mode='online' and $res">
          <link rel="stylesheet" type="text/css" 
                href="{p:styles/p:res[@id=$res]/@href}" />
        </xsl:if>
        <script language="javascript" src="{$scriptdir}pager.js" />
        <title>
          <xsl:value-of select="p:title" />
        </title>
      </head>
      <body onload="JavaScript:setPar('page',{$page}); setPar('subpage',{$subpage}); setPar('mode','{$mode}'); setPar('res','{$res}');">
        <xsl:if test="(p:slide[$page + 1] or 
                       p:slide[$page]/p:dynamic/p:element[$subpage + 1]) and
                      $mode='online'">
          <xsl:variable name="newpage">
            <xsl:choose>
              <xsl:when test="p:slide[$page]/p:dynamic/p:element[$subpage + 1]">
                <xsl:value-of select="$page" />
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="$page + 1" />
              </xsl:otherwise>
            </xsl:choose>
          </xsl:variable>
          <xsl:variable name="newsubpage">
            <xsl:choose>
              <xsl:when test="p:slide[$page]/p:dynamic/p:element[$subpage + 1]">
                <xsl:value-of select="$subpage + 1" />
              </xsl:when>
              <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
          </xsl:variable>
          <xsl:attribute name="onkeypress">
            <xsl:value-of select="concat(&quot;setPar('page',&quot;, 
                                         $newpage, 
                                         &quot;); setParTr('subpage',&quot;,
                                         $newsubpage, 
                                         ');')" />
          </xsl:attribute>
        </xsl:if>
        <!--
        <xsl:value-of select="$page" /> |
        <xsl:value-of select="$subpage" /> |
        <xsl:value-of select="$last" /> |
        <xsl:value-of select="$mode" /> |
        <xsl:value-of select="$res" /><br />
        -->
        <xsl:choose>
          <xsl:when test="$page=0 and $mode='online'">
            <h2><xsl:value-of select="p:title" /></h2>
            <h3><xsl:value-of select="$i18n/toc" /></h3>
             <blockquote class="contents">
               <xsl:for-each select="p:slide">
                 <xsl:variable name="p"><xsl:number/></xsl:variable>
                 <a href="JavaScript:setParTr('page',{$p});">
                   <xsl:value-of select="$i18n/page" />
                   <xsl:text> </xsl:text>
                   <xsl:value-of select="$p" />
                   <xsl:variable name="header" 
                        select=".//html:h1 | .//html:h2 | .//html:h3" />
                   <xsl:if test="$header">
                     <xsl:text>: </xsl:text>
                     <em><xsl:value-of select="$header" /></em>
                   </xsl:if>
                   <br />
                 </a>
               </xsl:for-each>
             </blockquote>
             <p class="footer"><xsl:apply-templates select="p:footer" /></p>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates 
                 select="p:slide[position()=$page or $mode='print']" />
            <xsl:if test="$mode='print'">
              <!-- endnote -->
              <p class="footer"><xsl:apply-templates select="p:footer" /></p>
            </xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>


  <xsl:template match="p:slide">
    <xsl:choose>
      <!-- print version (script) -->
      <xsl:when test="$mode='print'">
        <xsl:if test="@id">
          <a name="{@id}" />
        </xsl:if>
        <!-- page number upper right -->
        <table align="right" border="0" cellspacing="0" cellpadding="0">
        <tr><td>
            <xsl:variable name="p"><xsl:number /></xsl:variable>
            <a href="JavaScript:setPar('page',{$p}); setPar('subpage',0); setParTr('mode','online');">
              <xsl:value-of select="$p" />
              <xsl:text> / </xsl:text>
              <xsl:value-of select="count(/*/p:slide)" />
            </a>
        </td></tr></table>
        <xsl:apply-templates />
        <hr noshade="noshade" size="1" /> 
      </xsl:when>
      <!-- online version -->
      <xsl:otherwise>
        <table height="100%" width="100%"
               border="0" cellpadding="4" cellspacing="0">
          <col width="*" />
          <col />
          <!-- page contents --> 
          <tr>
            <td colspan="2" class="main" valign="top">
              <xsl:copy-of select="@*" />
              <xsl:apply-templates />
            </td>
          </tr>
          <!-- navigation area -->
          <tr valign="bottom" height="20">
            <td class="footer" style="white-space: nowrap">
              <!-- page number -->
              <a href="JavaScript:setPar('page', 0); setParTr('subpage', 0);">
                <strong>
                  <xsl:number />
                  <xsl:text> / </xsl:text>
                  <xsl:value-of select="count(/*/p:slide)" />
                </strong>
              </a>
              <xsl:text> &#xA0; &#xA0; &#xA0; &#xA0; </xsl:text>
              <xsl:apply-templates select="../p:footer" />
            </td>
            <td align="right" style="font-size: 10pt;">
              <!-- script link -->
              <a href="JavaScript:setParTr('mode', 'print');">
                <img src="{$imgdir}text.gif" alt="{$i18n/script}" border="0"/>
              </a>
              <xsl:text>&#xA0;&#xA0;</xsl:text>
              <!-- lower resolution -->
              <xsl:variable name="res-minus" 
                            select="/p:presentation/p:styles/p:res[@id=$res]
                                              /preceding-sibling::p:res[1]" />
              <xsl:choose>
                <xsl:when test="$res-minus">
                  <a href="JavaScript:setParTr('res', '{$res-minus/@id}');">
                    <img src="{$imgdir}generic_minus.gif"
                         alt="{$res-minus/@desc}" border="0" />
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}blank.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text>&#xA0;&#xA0;</xsl:text>
              <!-- higher resolution -->
              <xsl:variable name="res-plus" 
                            select="/p:presentation/p:styles/p:res[@id=$res]
                                              /following-sibling::p:res" />
              <xsl:choose>
                <xsl:when test="$res-plus">
                  <a href="JavaScript:setParTr('res', '{$res-plus/@id}');">
                    <img src="{$imgdir}generic_plus.gif"
                         alt="{$res-plus/@desc}" border="0" />
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}blank.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text>&#xA0;&#xA0;&#xA0;&#xA0;&#xA0;&#xA0;</xsl:text>
              <!-- arrows for moving back -->
              <xsl:choose>
                <xsl:when test="preceding-sibling::p:slide">
                  <xsl:variable name="newpage">
                    <xsl:choose>
                      <xsl:when test="$page - $step &lt; 1">1</xsl:when>
                      <xsl:otherwise>
                        <xsl:value-of select="$page - $step" />
                      </xsl:otherwise>
                    </xsl:choose>
                  </xsl:variable>
                  <a href="JavaScript:setPar('page',{$newpage}); setParTr('subpage',0);">
                    <img src="{$imgdir}double_left.gif" 
                      alt="{$i18n/page} {$newpage}" border="0"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}double_left_g.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:choose>
                <!-- this page has been entered via a direct link from
                     another page -->
                <xsl:when test="$last">
                  <a href="JavaScript:setPar('page',{$last}); setParTr('subpage',{count(../p:slide[$last]/p:dynamic/p:element)});">
                    <img src="{$imgdir}left_r.gif" 
                      alt="{$i18n/backto} {$i18n/page} {$last}" border="0"/>
                  </a>
                </xsl:when>
                <!-- one page back -->
                <xsl:when test="preceding-sibling::p:slide">
                  <a href="JavaScript:setPar('page',{$page - 1}); setParTr('subpage',0);">
                    <img src="{$imgdir}left.gif" 
                         alt="{$i18n/prev} {$i18n/page}"
                         border="0"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}left_g.gif" alt="" />              
                </xsl:otherwise>
              </xsl:choose>
              <!-- home -->
              <a href="{$home}">
                <img src="{$imgdir}home.gif" alt="{$i18n/home}" border="0"/>
              </a>
              <!-- moving forward -->
              <xsl:choose>
                <xsl:when test="following-sibling::p:slide">
                  <a href="JavaScript:setPar('page', {$page + 1}); setParTr('subpage',0);">
                    <img src="{$imgdir}right.gif" 
                         alt="{$i18n/next} {$i18n/page}"
                         border="0"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}right_g.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:choose>
                <xsl:when test="following-sibling::p:slide">
                  <xsl:variable name="successors" 
                                select="count(following-sibling::p:slide)" />
                  <xsl:variable name="newpage">
                    <xsl:choose>
                      <xsl:when test="$successors &gt; $step">
                        <xsl:value-of select="$page + $step" />
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:value-of select="$page + $successors" />
                      </xsl:otherwise>
                    </xsl:choose>
                  </xsl:variable>
                  <a href="JavaScript:setPar('page',{$newpage}); setParTr('subpage',0);">
                    <img src="{$imgdir}double_right.gif" 
                         alt="{$i18n/page} {$newpage}" border="0"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}double_right_g.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text>&#xA0;&#xA0;</xsl:text>
              <!-- page may have subelements -->
              <xsl:choose>
                <xsl:when test="p:dynamic/p:element[$subpage + 1]">
                  <a href="JavaScript:setParTr('subpage',{$subpage + 1});">
                    <img src="{$imgdir}continued.gif" alt="{$i18n/cont}"
                         border="0" />
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <img src="{$imgdir}blank.gif" alt="" />
                </xsl:otherwise>
              </xsl:choose>
            </td>
          </tr>
        </table>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="p:dynamic" />

  <!-- subelements will be displayed in the order of their definition
       within p:dynamic -->
  <xsl:template match="p:insert">
    <xsl:variable name="element" 
                  select="ancestor::p:slide/p:dynamic/p:element
                          [@id = current()/@ref]" />
    <!-- the following not(...) construction allows $subpage='last',
         which displays *all* subpages -->
    <xsl:variable name="display" 
                  select="$mode='print' or 
                  not(count($element/preceding-sibling::p:element) &gt;= 
                          $subpage)" />
    <xsl:variable name="insertion">
      <xsl:choose>
        <!-- has been parts specified? -->
        <xsl:when test="@part">
          <xsl:apply-templates 
               select="$element/p:part[@id = current()/@part]/node()">
            <xsl:with-param name="invisible" select="not($display)" />
          </xsl:apply-templates>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="$element/node()">
            <xsl:with-param name="invisible" select="not($display)" />
          </xsl:apply-templates>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:choose>
      <!-- if within an example then use different class 
           (different color for invisible etc) -->
      <xsl:when test="ancestor::html:*[contains(@class,'example')] and 
                      not($display)">
        <span class="exinvisible">
          <xsl:copy-of select="$insertion" />
        </span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:copy-of select="$insertion" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template match="p:footer">
    <xsl:apply-templates />
  </xsl:template>


  <!-- link elements: their address will be displayed as text, the target
       will be opened in a new window -->
  <xsl:template match="p:link">
    <xsl:param name="invisible" />
    <xsl:variable name="linkname">
      <xsl:choose>
        <xsl:when test="normalize-space()">
          <xsl:value-of select="." />
        </xsl:when>
        <xsl:when test="contains(@href,':')">
          <xsl:value-of select="@href" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="p:getBasename">
            <xsl:with-param name="path" select="@href" />
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$mode='print' and normalize-space()">
        <a href="{@href}">
          <xsl:value-of select="$linkname" />
        </a>
        [<xsl:value-of select="@href" />]
      </xsl:when>
      <xsl:when test="$invisible">
        <span class="invisible">
          <xsl:value-of select="$linkname" />
        </span>
      </xsl:when>
      <xsl:otherwise>
        <a href="{@href}" target="_blank">
          <xsl:value-of select="$linkname" />
        </a>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- determine the last part of a path (the filename) -->
  <xsl:template name="p:getBasename">
    <xsl:param name="path" />
    <xsl:choose>
      <xsl:when test="contains($path, '/')">
        <xsl:call-template name="p:getBasename">
          <xsl:with-param name="path" select="substring-after($path, '/')" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$path" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- direct link to another page -->
  <xsl:template match="p:slideref">
    <xsl:param name="invisible" />
    <xsl:variable name="p" 
                  select="count(/*/p:slide[@id=current()/@id]/
                                   preceding-sibling::p:slide) + 1" />
    <!-- id() doesn't work here (with IE) for some reason -->
    <xsl:choose>
      <xsl:when test="$mode='online'">
        <a href="JavaScript:setPar('last',{$page}); setParTr('page',{$p});">
          <xsl:if test="$invisible">
            <xsl:attribute name="class">invisible</xsl:attribute>
          </xsl:if>
          <xsl:value-of select="$p" />
        </a>
      </xsl:when>
      <xsl:otherwise>
        <a href="#{@id}"><xsl:value-of select="$p" /></a>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- script notes (for the printed version) -->
  <xsl:template match="p:note">
    <xsl:if test="$mode='print'">
      <div class="anno"><xsl:apply-templates /></div>
    </xsl:if>
  </xsl:template>


  <!-- copy all HTML elements (into the null namespace) -->
  <xsl:template match="html:*">
    <xsl:param name="invisible" />
    <xsl:element name="{local-name()}">
      <xsl:copy-of select="@*" />
      <!-- special treatment for <li>, <pre> and <div> -->
      <xsl:if test="$invisible and 
                    (self::html:li or self::html:pre or self::html:div)">
        <xsl:attribute name="class">
          <xsl:value-of select="concat('invisible ', @class)" />
        </xsl:attribute>
      </xsl:if>
      <!-- special treatment for <table> -->
      <xsl:if test="$invisible and self::html:table">
        <xsl:attribute name="border">0</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates>
        <xsl:with-param name="invisible" select="$invisible" />
      </xsl:apply-templates>
    </xsl:element>
  </xsl:template>

  <!-- special treatment for <img> -->
  <xsl:template match="html:img">
    <xsl:param name="invisible" />
    <img>
      <xsl:copy-of select="@*" />
      <xsl:if test="$invisible">
        <xsl:attribute name="src">icons/1trans.gif</xsl:attribute>
        <xsl:attribute name="alt" />
      </xsl:if>
    </img>
  </xsl:template>

  <!-- special treatment for <embed> -->
  <xsl:template match="html:embed">
    <xsl:param name="invisible" />
    <xsl:choose>
      <xsl:when test="$invisible">
        <img src="icons/1trans.gif">
          <xsl:copy-of select="@width | @height" />
        </img>
      </xsl:when>
      <xsl:otherwise>
        <embed>
          <xsl:copy-of select="@*" />
        </embed>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- special treatment for <a> -->
  <xsl:template match="html:a">
    <xsl:param name="invisible" />
    <xsl:choose>
      <xsl:when test="$invisible">
        <xsl:apply-templates>
          <xsl:with-param name="invisible" select="$invisible" />
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <a>
          <xsl:copy-of select="@*" />
          <xsl:attribute name="target">_blank</xsl:attribute>
          <xsl:apply-templates>
            <xsl:with-param name="invisible" select="$invisible" />
          </xsl:apply-templates>
        </a>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- "invisible" text nodes? -->
  <xsl:template match="text()[normalize-space()]">
    <xsl:param name="invisible" />
    <xsl:choose>
      <!-- invisible, not within <pre>, not dynamically inserted into
           <pre> or <div> with class="example" -->
      <xsl:when test="$invisible and not(ancestor::html:pre) and 
                         not(ancestor::p:slide//p:insert[
                              (ancestor::html:pre|ancestor::html:div)
                                 [contains(@class,'example')] and
                              concat(current()/ancestor::p:element/@id,'|',
                                     current()/ancestor::p:part/@id) = 
                              concat(@ref,'|',@part)])">
        <span class="invisible">
          <xsl:value-of select="." />
        </span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="." />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- unknown elements -->
  <xsl:template match="*">
    <xsl:text />&lt;<xsl:value-of select="name()"/>&gt;<xsl:text />
    <xsl:apply-templates />
    <xsl:text />&lt;/<xsl:value-of select="name()"/>&gt;<xsl:text />
  </xsl:template>

</xsl:stylesheet>
