<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Templates defined:
		series:column
			Draws a series.
		labels:column
			Draws x-axis labels.
		drawColumnSkeleton:
			Draws a column graph skeleton.
===========================================================================
	Global variables needed:
		minValue, valueRange, graphTopValPerc
		seriesCount, valueCount
		topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="columnWidth" select="1000 div ($seriesCount*$valueCount+$valueCount+1)"/>
	<xsl:template match="series" mode="column">
		<!--
		===========================================================================
		series:column
			Draws a series.
		global variables needed:
			minValue, valueRange, graphTopValPerc, columnWidth, seriesCount
		===========================================================================-->
		<xsl:variable name="seriesIndex" select="count(preceding-sibling::series)"/>
		<g style="fill:{@color}; stroke:black; stroke-width:1; font-size:20; text-anchor: middle">
			<!--
			===========================================================================
			Draw name of this the series to the legend
			===========================================================================-->
			<text x="1050" y="{115+$seriesIndex*30}" style="text-anchor: start">
				<xsl:value-of select="@name"/>
			</text>
			<!--
			===========================================================================
			Draw the columns
			===========================================================================-->
			<xsl:for-each select="value">
				<xsl:variable name="value" select="."/>
				<xsl:variable name="valueIndex" select="position()-1"/>
				<xsl:variable name="columnHeight" select="(($value -$minValue) div $valueRange)*10*$graphTopValPerc"/>
				<xsl:variable name="columnX" select="$columnWidth*(1+($seriesCount+1)*$valueIndex+$seriesIndex)"/>
				<xsl:variable name="columnY" select="1000-$columnHeight"/>
				<!--
				=======================================================================
				Draw the column itself
				=======================================================================-->
				<rect x="{$columnX}" y="{$columnY}" width="{$columnWidth}" height="{$columnHeight}"/>
				<!--
				=======================================================================
				Draw the value on the top of this column
				=======================================================================-->
				<text x="{$columnX+($columnWidth div 2)}" y="{$columnY -4}">
					<xsl:value-of select="$value"/>
				</text>
			</xsl:for-each>
		</g>
	</xsl:template>
	<xsl:template match="labels" mode="column">
		<!--
		===========================================================================
		labels:column
			Draws x-axis labels.
		===========================================================================-->
		<xsl:call-template name="x-axisLabels"/>
	</xsl:template>
	<xsl:template name="drawColumnSkeleton">
		<!--
		==========================================================================
		drawColumnSkeleton:
			Draws a column graph skeleton.
		global variables needed:
			topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
		==========================================================================-->
		<xsl:call-template name="drawSkeleton"/>
		<!--
		=========================================================================
		Draw y-axis 3 small lines
		=========================================================================-->
		<g style="fill:none; stroke:grey; stroke-width:2">
			<line x1="-7" y1="0" x2="0" y2="0"/>
			<line x1="-7" y1="{$midValueCoord}" x2="0" y2="{$midValueCoord}"/>
			<line x1="-7" y1="1000" x2="0" y2="1000"/>
			<!--
			========================================================================
			Draw y-axis zero line if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<line x1="-7" y1="{$zeroLineCoord}" x2="1000" y2="{$zeroLineCoord}" style="stroke:black"/>
			</xsl:if>
		</g>
		<!--
		=========================================================================
		Draw y-axis 3 small lines labels
		=========================================================================-->
		<g style="font-size:20; text-anchor:end">
			<text x="-10" y="1007">
				<xsl:value-of select="$bottomValue"/>
			</text>
			<text x="-10" y="{$midValueCoord+7}">
				<xsl:value-of select="$midValue"/>
			</text>
			<text x="-10" y="7">
				<xsl:value-of select="$topValue"/>
			</text>
			<!--
			========================================================================
			Draw y-axis zero line label if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<text x="-10" y="{$zeroLineCoord+7}">0</text>
			</xsl:if>
		</g>
	</xsl:template>
</xsl:stylesheet>
