<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Templates defined:
		series:line
			Draws a series.
		labels:line
			Draws x-axis labels.
		drawLineSkeleton:
			Draws a line graph skeleton
===========================================================================
	Global variables needed:
		minValue, valueRange, graphTopValPerc
		seriesCount, valueCount
		topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="lineRectWidth" select="1000 div ($seriesCount*$valueCount+$valueCount+1)"/>
	<xsl:template match="series" mode="line">
		<!--
		===========================================================================
		series:line
			Draws a series.
		global variables needed:
			minValue, valueRange, graphTopValPerc, columnWidth, seriesCount
		===========================================================================-->
		<xsl:variable name="seriesIndex" select="count(preceding-sibling::series)"/>
		<xsl:variable name="valueCount" select="count(./value)"/>
		<g style="fill:{@color};font-size:20;stroke:black; stroke-width:1;  text-anchor: start">
			<!--
			===========================================================================
			Draw name of the this series to the legend
			===========================================================================-->
			<text x="1050" y="{115+$seriesIndex*30}" style="text-anchor: start">
				<xsl:value-of select="@name"/>
			</text>
			<xsl:variable name="path">
				<xsl:for-each select="value">
					<xsl:variable name="value" select="."/>
					<xsl:variable name="valueIndex" select="position()-1"/>
					<xsl:variable name="x" select="$lineRectWidth*(1+$valueIndex*($seriesCount+1)+($seriesCount div 2))"/>
					<xsl:variable name="y" select="1000-(($value -$minValue)*((10*$graphTopValPerc)div $valueRange))"/>
					<xsl:choose>
						<xsl:when test="$valueIndex=0">
							<xsl:value-of select="concat('M',$x,',',$y,' ')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="concat('L',$x,',',$y,' ')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:variable>
			<!--
			===========================================================================
			Draw the lines
			===========================================================================-->
			<path>
				<xsl:attribute name="style">fill:none; stroke:<xsl:value-of select="@color"/>; stroke-width:2</xsl:attribute>
				<xsl:attribute name="d"><xsl:value-of select="$path"/></xsl:attribute>
			</path>
			<!--
			===========================================================================
			Draw the points
			===========================================================================-->
			<xsl:for-each select="value">
				<xsl:variable name="value" select="."/>
				<xsl:variable name="valueIndex" select="position()-1"/>
				<xsl:variable name="x" select="$lineRectWidth*(1+$valueIndex*($seriesCount+1)+($seriesCount div 2))"/>
				<xsl:variable name="y" select="1000-(($value -$minValue)*((10*$graphTopValPerc)div $valueRange))"/>
				<!--
				=======================================================================
				Draw the point
				=======================================================================-->
				<circle cx="{$x}" cy="{$y}" r="3"/>
				<!--
				=======================================================================
				Draw the value on the top of this point
				=======================================================================-->
				<text x="{$x+4}" y="{$y -4}">
					<xsl:value-of select="$value"/>
				</text>
			</xsl:for-each>
		</g>
	</xsl:template>
	<xsl:template match="labels" mode="line">
		<!--
		===========================================================================
		labels:line
			Draws x-axis labels.
		===========================================================================-->
		<xsl:call-template name="x-axisLabels"/>
	</xsl:template>
	<xsl:template name="drawLineSkeleton">
		<!--
		==========================================================================
		drawLineSkeleton:
			Draws a line graph skeleton.
		global variables needed:
			topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
		==========================================================================-->
		<xsl:call-template name="drawSkeleton"/>
		<!--
		=========================================================================
		Draw y-axis 3 small lines
		=========================================================================-->
		<g style="fill:none; stroke:grey; stroke-width:2">
			<line x1="-7" y1="0" x2="0" y2="0"/>
			<line x1="-7" y1="{$midValueCoord}" x2="0" y2="{$midValueCoord}"/>
			<line x1="-7" y1="1000" x2="0" y2="1000"/>
			<!--
			========================================================================
			Draw y-axis zero line if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<line x1="-7" y1="{$zeroLineCoord}" x2="1000" y2="{$zeroLineCoord}" style="stroke:black"/>
			</xsl:if>
		</g>
		<!--
		=========================================================================
		Draw y-axis 3 small lines labels
		=========================================================================-->
		<g style="font-size:20; text-anchor:end">
			<text x="-10" y="1007">
				<xsl:value-of select="$bottomValue"/>
			</text>
			<text x="-10" y="{$midValueCoord+7}">
				<xsl:value-of select="$midValue"/>
			</text>
			<text x="-10" y="7">
				<xsl:value-of select="$topValue"/>
			</text>
			<!--
			========================================================================
			Draw y-axis zero line label if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<text x="-10" y="{$zeroLineCoord+7}">0</text>
			</xsl:if>
		</g>
	</xsl:template>
</xsl:stylesheet>
