<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Main StyleSheet
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:svg="http://www.w3.org/2000/svg">
	<!--
	===========================================================================
	Import functions and global variables
	===========================================================================-->
	<xsl:import href="functions.xsl"/>
	<xsl:import href="globals.xsl"/>
	<!--
	===========================================================================
	Import graph types
	===========================================================================-->
	<xsl:import href="area.xsl"/>
	<xsl:import href="bar.xsl"/>
	<xsl:import href="column.xsl"/>
	<xsl:import href="line.xsl"/>
	<xsl:import href="point.xsl"/>
	<xsl:import href="pie.xsl"/>

    <!--  -->
	<xsl:output method="xml" indent="yes" doctype-public="-//W3C//DTD SVG 20010904//EN" doctype-system="http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd"/>
	<xsl:template match="/graph">
		<!--
		===========================================================================
			The main matching to root element of a graph
		===========================================================================
			Rectangle which makes the Canvas
			1000x1000px for main picture
			+	150px over left and right (yTitle and legend)
			+	100px over up and down (xTitle and graphTitle)
		===========================================================================-->
		<svg width="100%" height="100%" viewBox="-150 -100 1300 1200">
			<rect x="-1000" y="-1000" width="200%" height="200%" style="fill:{$graphBgColor}; stroke-width:0"/>
			<!--
			===========================================================================
				Draw entire graph.
			===========================================================================-->
			<xsl:choose>
				<xsl:when test="$graphType='area'">
					<xsl:call-template name="drawAreaSkeleton"/>
					<xsl:apply-templates mode="area"/>
				</xsl:when>
				<xsl:when test="$graphType='bar'">
					<xsl:call-template name="drawBarSkeleton"/>
					<xsl:apply-templates mode="bar"/>
				</xsl:when>
				<xsl:when test="$graphType='column'">
					<xsl:call-template name="drawColumnSkeleton"/>
					<xsl:apply-templates mode="column"/>
				</xsl:when>
				<xsl:when test="$graphType='point'">
					<xsl:call-template name="drawPointSkeleton"/>
					<xsl:apply-templates mode="point"/>
				</xsl:when>
				<xsl:when test="$graphType='line'">
					<xsl:call-template name="drawLineSkeleton"/>
					<xsl:apply-templates mode="line"/>
				</xsl:when>
				<!--
				===========================================================================
					Pie graph is an exception
				===========================================================================-->
				<xsl:when test="$graphType='pie'">
					<xsl:apply-templates mode="pie"/>
				</xsl:when>
			</xsl:choose>
		</svg>
	</xsl:template>
</xsl:stylesheet>
