<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Templates defined:
		series:pie
			Draws a pie.
		doTheJob:
			Recursively calls itself with default value position =1 and draws the pieces.
		drawSegment:
			Draws a pie segment.
===========================================================================
	Global variables needed:
			graphTitle, graphLegend, valueCount
			valueCount
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:math="http://exslt.org/math" extension-element-prefixes="math">
	<xsl:template match="series" mode="pie">
		<!--
		===========================================================================
		series:pie
			Draws a pie.
		global variables needed:
			graphTitle, graphLegend, valueCount
		===========================================================================-->
		<!--
		===========================================================================
		Test if we got sin and cos functions
		===========================================================================-->
		<xsl:variable name="supportForSinCos">
			<xsl:choose>
				<xsl:when test="function-available('math:sin') and function-available('math:cos')">yes</xsl:when>
				<xsl:otherwise>
					<xsl:message terminate="yes">
						<xsl:text>Your XSLT processor does not support math:sin or math:cos functions!</xsl:text>
						<xsl:text>Use some exslt powered processor instead, SAXON for example.</xsl:text>
					</xsl:message>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--
		=========================================================================
		Draws whole pie graph
		=========================================================================-->
		<!--
		=========================================================================
		Draw graph title
		=========================================================================-->
		<text x="500" y="-40" style="font-size:40; text-anchor:middle">
			<xsl:value-of select="$graphTitle"/>
		</text>
		<!--
		=========================================================================
		Draw the legend lable
		=========================================================================-->
		<text x="1050" y="65" style="font-size:30;">
			<xsl:value-of select="$graphLegend"/>
		</text>
		<xsl:variable name="valueSum" select="sum(./value)"/>
		<xsl:call-template name="doTheJob">
			<xsl:with-param name="valueCount" select="$valueCount"/>
			<xsl:with-param name="valueSum" select="$valueSum"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="doTheJob">
		<!--
		===========================================================================
		doTheJob:
			Recursively calls itself with default value position =1 and draws the pieces.
		global variables needed:
			valueCount
		===========================================================================-->
		<xsl:param name="valueCount"/>
		<xsl:param name="valueSum"/>
		<xsl:param name="percDone" select="0"/>
		<xsl:param name="valuePosition" select="1"/>
		<xsl:variable name="value" select="value[$valuePosition]"/>
		<xsl:variable name="valueLabel" select="value[$valuePosition]/@label"/>
		<xsl:variable name="valueColor" select="value[$valuePosition]/@color"/>
		<xsl:variable name="percOfSum" select="$value div $valueSum"/>
		<xsl:choose>
			<xsl:when test="$valueCount = 1">
				<!--
				===========================================================================
				Special case for only one value
				===========================================================================-->
				<!--
				===========================================================================
				Draw a circle
				===========================================================================-->
				<path fill="{$valueColor}" stroke="black" d="M500,200 a300,300 0 1 1 0,600 a300,300 0 1 1 0,-600"/>
				<text text-anchor="middle" x="500" y="800" font-size="25" dy="25">
					<xsl:value-of select="concat($valueLabel,' (100%)')"/>
				</text>
				<!--
				===========================================================================
				Draw this circle legend
				===========================================================================-->
				<text x="1050" y="115" style="font-size:22; text-anchor: start">
					<xsl:value-of select="concat($valueLabel,': ',$value)"/>
				</text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="drawSegment">
					<xsl:with-param name="angle" select="360 * $percOfSum"/>
					<xsl:with-param name="startAngle" select="360 * $percDone"/>
					<xsl:with-param name="color" select="$valueColor"/>
					<xsl:with-param name="cX" select="500"/>
					<xsl:with-param name="cY" select="500"/>
					<xsl:with-param name="r" select="300"/>
					<xsl:with-param name="label" select="$valueLabel"/>
					<xsl:with-param name="value" select="$value"/>
					<xsl:with-param name="valuePosition" select="$valuePosition"/>
					<xsl:with-param name="percOfSum" select="$percOfSum"/>
				</xsl:call-template>
				<xsl:if test="$valuePosition&lt;$valueCount">
					<xsl:call-template name="doTheJob">
						<xsl:with-param name="valueCount" select="$valueCount"/>
						<xsl:with-param name="valueSum" select="$valueSum"/>
						<xsl:with-param name="percDone" select="$percDone + $percOfSum"/>
						<xsl:with-param name="valuePosition" select="$valuePosition + 1"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="drawSegment">
		<!--
		===========================================================================
		drawSegment:
			Draws a pie segment.
		===========================================================================-->
		<xsl:param name="startAngle" select="0"/>
		<xsl:param name="angle"/>
		<xsl:param name="color"/>
		<xsl:param name="cX"/>
		<xsl:param name="cY"/>
		<xsl:param name="r"/>
		<xsl:param name="label"/>
		<xsl:param name="value"/>
		<xsl:param name="valuePosition"/>
		<xsl:param name="percOfSum"/>
		<xsl:variable name="PI" select="math:constant('PI',8)"/>
		<xsl:variable name="deg2rad" select="$PI div 180"/>
		<xsl:variable name="fullAngle" select="($startAngle + $angle)*$deg2rad"/>
		<xsl:variable name="halfAngleDeg" select="$startAngle + ($angle div 2)"/>
		<xsl:variable name="halfAngle" select="$halfAngleDeg*$deg2rad"/>
		<xsl:variable name="x0" select="$cX"/>
		<xsl:variable name="y0" select="$cY"/>
		<xsl:variable name="x1" select="math:sin($startAngle*$deg2rad)*$r"/>
		<xsl:variable name="y1" select="-math:cos($startAngle*$deg2rad)*$r"/>
		<xsl:variable name="x2" select="(math:sin($fullAngle)*$r)-$x1"/>
		<xsl:variable name="y2" select="-(math:cos($fullAngle)*$r)-$y1"/>
		<xsl:variable name="labelQuandrant" select="floor(($halfAngleDeg mod 360) div 90)"/>
		<xsl:variable name="textAnchor">
			<xsl:choose>
				<xsl:when test="$labelQuandrant &lt; 2">
					<xsl:text>start</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>end</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="labelDY">
			<xsl:choose>
				<xsl:when test="($labelQuandrant mod 3) = 0">
					<xsl:text>-10</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>15</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="labelX" select="$x0 + (math:sin($halfAngle)*($r+10))"/>
		<xsl:variable name="labelY" select="$y0 - (math:cos($halfAngle)*($r+10))"/>
		<xsl:variable name="valuePerc" select="format-number($percOfSum,'.##%')"/>
		<path fill="{$color}" stroke="black" stroke-width="1" opacity="0.8" d="M{$x0},{$y0} l{$x1},{$y1} a 300 300 0 {number($angle &gt;= 180)} 1 {$x2},{$y2} L{$x0},{$y0}"/>
		<text style="text-anchor:{$textAnchor}; font-size:25" x="{$labelX}" y="{$labelY}" dy="{$labelDY}">
			<xsl:value-of select="concat($label,' (',$valuePerc,')')"/>
		</text>
		<!--
		===========================================================================
		Draw this piece legend
		===========================================================================-->
		<text x="1050" y="{115+30*($valuePosition - 1)}" style="fill:{$color}; stroke:black; stroke-width:1; font-size:22; text-anchor: start">
			<xsl:value-of select="concat($label,': ',$value)"/>
		</text>
	</xsl:template>
</xsl:stylesheet>
