<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:exsl="http://exslt.org/common"
		xmlns:ng="http://docbook.org/docbook-ng"
		xmlns:db="http://docbook.org/ns/docbook"
                version="1.0">

<xsl:include href="default.xsl"/>

<xsl:template match="speakernotes" mode="olink.mode">
  <xsl:call-template name="obj"/>
</xsl:template>

<xsl:template match="slides|foilgroup|foil" mode="olink.mode">
  <xsl:call-template name="div"/>
</xsl:template>

<!-- ==================================================================== -->

<xsl:template match="/">
  <xsl:choose>
    <xsl:when test="function-available('exsl:node-set')
		    and (*/self::ng:* or */self::db:*)">
      <!-- Hack! If someone hands us a DocBook V5.x or DocBook NG document,
	   toss the namespace and continue. Someday we'll reverse this logic
	   and add the namespace to documents that don't have one.
	   But not before the whole stylesheet has been converted to use
	   namespaces. i.e., don't hold your breath -->
      <xsl:message>Stripping NS from DocBook 5/NG document.</xsl:message>
      <xsl:variable name="nons">
	<xsl:apply-templates mode="stripNS"/>
      </xsl:variable>
      <xsl:message>Processing stripped document.</xsl:message>
      <xsl:apply-templates select="exsl:node-set($nons)"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:choose>
	<xsl:when test="$rootid != ''">
	  <xsl:choose>
	    <xsl:when test="count(key('id',$rootid)) = 0">
	      <xsl:message terminate="yes">
		<xsl:text>ID '</xsl:text>
		<xsl:value-of select="$rootid"/>
		<xsl:text>' not found in document.</xsl:text>
	      </xsl:message>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:if test="$collect.xref.targets = 'yes' or
			    $collect.xref.targets = 'only'">
		<xsl:apply-templates select="key('id', $rootid)"
				     mode="collect.targets"/>
	      </xsl:if>
	      <xsl:if test="$collect.xref.targets != 'only'">
		<xsl:apply-templates select="key('id',$rootid)"
				     mode="process.root"/>
		<xsl:if test="$tex.math.in.alt != ''">
		  <xsl:apply-templates select="key('id',$rootid)"
				       mode="collect.tex.math"/>
		</xsl:if>
		<xsl:if test="$generate.manifest != 0">
		  <xsl:call-template name="generate.manifest">
		    <xsl:with-param name="node" select="key('id',$rootid)"/>
		  </xsl:call-template>
		</xsl:if>
	      </xsl:if>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:if test="$collect.xref.targets = 'yes' or
			$collect.xref.targets = 'only'">
	    <xsl:apply-templates select="/" mode="collect.targets"/>
	  </xsl:if>
	  <xsl:if test="$collect.xref.targets != 'only'">
	    <xsl:apply-templates select="/" mode="process.root"/>
	    <xsl:if test="$tex.math.in.alt != ''">
	      <xsl:apply-templates select="/" mode="collect.tex.math"/>
	    </xsl:if>
	    <xsl:if test="$generate.manifest != 0">
	      <xsl:call-template name="generate.manifest">
		<xsl:with-param name="node" select="/"/>
	      </xsl:call-template>
	    </xsl:if>
	  </xsl:if>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="*" mode="process.root">
	<xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>
