<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        version="1.0">

    <xsl:import href="http://docbook.sourceforge.net/release/slides/xsl/html/default.xsl"/>
    <xsl:include href="../common/id.as.filename.xsl"/>

    <xsl:include href="../common/profile-navigation.xsl"/>				

   
    <!-- to highlight sources -->
    <xsl:include href="../code2html/code2html.xsl"/>

    <xsl:param name="filename" select="'index.html'"/>

    <!-- e-learning params -->
    <xsl:param name="el.faculty"/>
    <xsl:param name="el.term"/>
    <xsl:param name="el.subject"/>

    <!-- site-unique id of this doc -->
    <xsl:param name="el.doc.id"/>

    <xsl:param name="use.id.as.filename" select="1"/>

    <xsl:param name="el.render.slides.topnav" select="0"/>

    <xsl:template name="top-nav">
        <xsl:param name="home"/>
        <xsl:param name="up"/>
        <xsl:param name="next"/>
        <xsl:param name="prev"/>
        <xsl:param name="tocfile" select="$toc.html"/>
        <div class="navhead">
            <table width="100%" border="0" cellpadding="0" cellspacing="0"
                    summary="Navigation">
                <tr>
                    <xsl:call-template name="generate.toc.hide.show"/>
                    <td align="left" width="20%">
                        <xsl:choose>
                            <xsl:when test="$prev">
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:apply-templates select="$prev" mode="filename"/>
                                    </xsl:attribute>

                                    <img alt="Prev" border="0">
                                        <xsl:attribute name="src">
                                            <xsl:call-template name="prev.image"/>
                                        </xsl:attribute>
                                    </img>
                                </a>
                            </xsl:when>
                            <xsl:otherwise>&#160;</xsl:otherwise>
                        </xsl:choose>
                    </td>
                    <xsl:if test="$el.render.slides.topnav!=0">
                        <td align="left">
                            <xsl:apply-templates select="." mode="el-security-links"/>
                        </td>
                        <td align="left">
                            <xsl:apply-templates select="." mode="el-os-links"/>
                        </td>
                        <td align="left">
                            <xsl:apply-templates select="." mode="el-arch-links"/>
                        </td>
                        <td align="left">
                            <xsl:apply-templates select="." mode="el-userlevel-links"/>
                        </td>
                        <td align="left">
                            <xsl:apply-templates select="." mode="el-condition-links"/>
                        </td>
                    </xsl:if>
                    <td align="center"></td>
                    <td align="center" width="60%">
                        <xsl:variable name="prestitle">
                            <xsl:value-of select="(/slides/slidesinfo/title |/slides/title)[1]"/>
                        </xsl:variable>
                    </td>
                    <td align="right" width="20%">
                        <xsl:choose>
                            <xsl:when test="$next">
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:apply-templates select="$next" mode="filename"/>
                                    </xsl:attribute>

                                    <img alt="Next" border="0">
                                        <xsl:attribute name="src">
                                            <xsl:call-template name="next.image"/>
                                        </xsl:attribute>
                                    </img>
                                </a>
                            </xsl:when>
                            <xsl:otherwise>&#160;</xsl:otherwise>
                        </xsl:choose>
                    </td>
                </tr>
            </table>
            <hr class="top-nav-sep"/>
        </div>
    </xsl:template>

<!-- ====================================================================== -->

    <xsl:template name="titlepage-top-nav">
        <xsl:param name="home"/>
        <xsl:param name="up"/>
        <xsl:param name="next"/>
        <xsl:param name="prev"/>
        <xsl:param name="tocfile" select="$toc.html"/>

        <div class="navhead">
            <table width="100%" border="0" cellpadding="0" cellspacing="0"
                    summary="Navigation">
                <tr>
                    <td align="left" width="10%">
                        <span class="toclink">
                            <a href="{$toc.html}">
                                <xsl:call-template name="gentext">
                                    <xsl:with-param name="key">TableofContents</xsl:with-param>
                                </xsl:call-template>
                            </a>
                        </span>
                    </td>
                    <xsl:if test="$el.render.slides.topnav!=0">
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-security-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-os-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-arch-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-userlevel-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-condition-links"/>
                    </td>
                    </xsl:if>
                    <td align="center"></td>
                    <td align="center" width="80%">
                        <xsl:text>&#160;</xsl:text>
                    </td>
                    <td align="right" width="10%">
                        <xsl:text>&#160;</xsl:text>
                    </td>
                </tr>
            </table>
        </div>
    </xsl:template>

    <xsl:template name="toc-top-nav">
        <xsl:param name="home"/>
        <xsl:param name="up"/>
        <xsl:param name="next"/>
        <xsl:param name="prev"/>
        <xsl:param name="tocfile" select="$toc.html"/>

        <xsl:if test="$el.render.slides.topnav!=0">
        <div class="navhead">
            <table width="100%" border="0" cellpadding="0" cellspacing="0"
                    summary="Navigation">
                <tr>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-security-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-os-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-arch-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-userlevel-links"/>
                    </td>
                    <td align="left">
                        <xsl:apply-templates select="." mode="el-condition-links"/>
                    </td>
                    <td align="center"></td>
                </tr>
            </table>
        </div>
	</xsl:if>
    </xsl:template>

</xsl:stylesheet>
