<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Templates defined:
		series:bar
			Draws a series.
		labels:bar
			Draws y-axis labels.
		drawBarSkeleton:
			Draws a bar graph skeleton.
===========================================================================
	Global variables needed:
		minValue, valueRange, graphTopValPerc
		seriesCount, valueCount
		topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="barHeight" select="1000 div ($seriesCount*$valueCount+$valueCount+1)"/>
	<xsl:template match="series" mode="bar">
		<!--
		===========================================================================
		series:bar
			Draws a series.
		global variables needed:
			minValue, valueRange, graphTopValPerc, barHeight, seriesCount
		===========================================================================-->
		<xsl:variable name="seriesIndex" select="count(preceding-sibling::series)"/>
		<g style="fill:{@color}; stroke:black; stroke-width:1; font-size:20; text-anchor: start">
			<!--
			===========================================================================
			Draw name of the this series to the legend
			===========================================================================-->
			<text x="1050" y="{115+$seriesIndex*30}" style="text-anchor: start">
				<xsl:value-of select="@name"/>
			</text>
			<!--
			===========================================================================
			Draw the bars
			===========================================================================-->
			<xsl:for-each select="value">
				<xsl:variable name="value" select="."/>
				<xsl:variable name="valueIndex" select="position()-1"/>
				<xsl:variable name="barWidth" select="(($value -$minValue) div $valueRange)*10*$graphTopValPerc"/>
				<xsl:variable name="barY" select="$barHeight*(1+($seriesCount+1)*$valueIndex+$seriesIndex)"/>
				<!--
				=======================================================================
				Draw the bar itself
				=======================================================================-->
				<rect x="0" y="{$barY}" width="{$barWidth}" height="{$barHeight}"/>
				<!--
				=======================================================================
				Draw the value nearby this bar
				=======================================================================-->
				<text x="{$barWidth+4}" y="{$barY+($barHeight div 2)+7}">
					<xsl:value-of select="$value"/>
				</text>
			</xsl:for-each>
		</g>
	</xsl:template>
	<xsl:template match="labels" mode="bar">
		<!--
		===========================================================================
		labels:bar
			Draws y-axis labels.
		===========================================================================-->
		<xsl:call-template name="y-axisLabels"/>
	</xsl:template>
	<xsl:template name="drawBarSkeleton">
		<!--
		==========================================================================
		drawBarSkeleton:
			Draws a bar graph skeleton.
		global variables needed:
			topValue, midValue, midValueCoord, bottomValue,  zeroLineCoord
		==========================================================================-->
		<xsl:call-template name="drawSkeleton"/>
		<!--
		=========================================================================
		Draw x-axis 3 small lines
		=========================================================================-->
		<g style="fill:none; stroke:grey; stroke-width:2">
			<line x1="0" y1="1000" x2="0" y2="1007"/>
			<line x1="$midValueCoord" y1="1000" x2="$midValueCoord" y2="1007"/>
			<line x1="1000" y1="1000" x2="1000" y2="1007"/>
			<!--
			========================================================================
			Draw x-axis zero line if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<line x1="{1000-$zeroLineCoord}" y1="0" x2="{1000-$zeroLineCoord}" y2="1007" style="stroke:black"/>
			</xsl:if>
		</g>
		<!--
		=========================================================================
		Draw x-axis 3 small lines labels
		=========================================================================-->
		<g style="font-size:20; text-anchor:middle">
			<text x="0" y="1027">
				<xsl:value-of select="$bottomValue"/>
			</text>
			<text x="{$midValueCoord}" y="1027">
				<xsl:value-of select="$midValue"/>
			</text>
			<text x="1000" y="1027">
				<xsl:value-of select="$topValue"/>
			</text>
			<!--
			========================================================================
			Draw x-axis zero line label if needed
			========================================================================-->
			<xsl:if test="$bottomValue &lt;0">
				<text x="{1000-$zeroLineCoord}" y="1027">0</text>
			</xsl:if>
		</g>
	</xsl:template>
</xsl:stylesheet>
