<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
===========================================================================
	Templates defined:
		drawSkeleton:
			Draws the common skeleton of a graph (axis,titles,legend).
		x-axisLabels:
			Draws labels for x-axis.
		y-axisLabels:
			Draws labels for y-axis.
===========================================================================
	Global variables needed:
		seriesCount, valueCount, elementWidth
		graphTitle,graphLegend,graphXTitle,graphYTitle
===========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:template name="drawSkeleton">
		<!--
		===========================================================================
		drawSkeleton:
			Draws the common skeleton of a graph (axis,titles,legend).
		global variables needed:
			graphTitle,graphLegend,graphXTitle,graphYTitle
		===========================================================================-->
		<xsl:param name="type" select="doplnit"/>
		<g style="fill:none; stroke:grey; stroke-width:4">
			<!--
			=========================================================================
			Draw x-axis
			=========================================================================-->
			<line x1="0" y1="1000" x2="1000" y2="1000"/>
			<!--
			=========================================================================
			Draw x-axis
			=========================================================================-->
			<line x1="0" y1="0" x2="0" y2="1000"/>
		</g>
		<!--
		=========================================================================
		Draw graph title
		=========================================================================-->
		<text x="500" y="-40" style="font-size:40; text-anchor:middle">
			<xsl:value-of select="$graphTitle"/>
		</text>
		<!--
		=========================================================================
		Draw the legend lable
		=========================================================================-->
		<text x="1050" y="65" style="font-size:30">
			<xsl:value-of select="$graphLegend"/>
		</text>
		<!--
		=========================================================================
		Draw x-axis title
		=========================================================================-->
		<text x="500" y="1070" style="font-size:30; text-anchor:middle">
			<xsl:value-of select="$graphXTitle"/>
		</text>
		<!--
		=========================================================================
		Draw y-axis title
		=========================================================================-->
		<g transform="translate(-140 500) rotate(180) translate(140, -500)">
			<text x="-140" y="500" style="font-size:30; text-anchor:start; writing-mode:tb" transform="translate(0,-50%)">
				<xsl:value-of select="$graphYTitle"/>
			</text>
		</g>
	</xsl:template>
	<xsl:template name="x-axisLabels">
		<!--
		===========================================================================
		x-axisLabels:
			Draws labels for x-axis.
		global variables needed:
			seriesCount, valueCount, elementWidth
		===========================================================================-->
		<!--
		===========================================================================
		Draw x-axis small lines
		===========================================================================-->
		<g style="fill:none; stroke:grey; stroke-width:2">
			<xsl:for-each select="label[position()&lt;=$valueCount]">
				<xsl:variable name="index" select="position()-1"/>
				<xsl:variable name="elementMidPoint" select="$elementWidth*($index*($seriesCount+1)+1+($seriesCount div 2))"/>
				<line x1="{$elementMidPoint}" y1="1000" x2="{$elementMidPoint}" y2="1007"/>
			</xsl:for-each>
		</g>
		<!--
		===========================================================================
		Draw x-axis labels
		===========================================================================-->
		<g style="font-size:20; text-anchor:middle">
			<xsl:for-each select="label[position()&lt;=$valueCount]">
				<xsl:variable name="index" select="position()-1"/>
				<xsl:variable name="elementMidPoint" select="$columnWidth*($index*($seriesCount+1)+1+($seriesCount div 2))"/>
				<text x="{$elementMidPoint}" y="1027">
					<xsl:value-of select="."/>
				</text>
			</xsl:for-each>
		</g>
	</xsl:template>
	<xsl:template name="y-axisLabels">
		<!--
		===========================================================================
		y-axisLabels:
			Draws labels for y-axis.
		global variables needed:
			seriesCount, valueCount, elementWidth
		===========================================================================-->
		<!--
		===========================================================================
		Draw y-axis small lines
		===========================================================================-->
		<g style="fill:none; stroke:grey; stroke-width:2">
			<xsl:for-each select="label[position()&lt;=$valueCount]">
				<xsl:variable name="index" select="position()-1"/>
				<xsl:variable name="elementMidPoint" select="$elementWidth*($index*($seriesCount+1)+1+($seriesCount div 2))"/>
				<line x1="-7" y1="{$elementMidPoint}" x2="0" y2="{$elementMidPoint}"/>
			</xsl:for-each>
		</g>
		<!--		
		===========================================================================
		Draw y-axis labels
		===========================================================================-->
		<g style="font-size:20; text-anchor:end">
			<xsl:for-each select="label[position()&lt;=$valueCount]">
				<xsl:variable name="index" select="position()-1"/>
				<xsl:variable name="elementMidPoint" select="$barHeight*($index*($seriesCount+1)+1+($seriesCount div 2))"/>
				<text x="-10" y="{$elementMidPoint+7}">
					<xsl:value-of select="."/>
				</text>
			</xsl:for-each>
		</g>
	</xsl:template>
</xsl:stylesheet>
