<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (c) 2004 Michal Vaněk-->
<!--
==========================================================================
	Global variables (for all graph types)
	To be accessed from wherever or is it more elegant this way
==========================================================================-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:math="http://exslt.org/math" extension-element-prefixes="math">
	<xsl:variable name="graphType" select="/graph/@type"/>
	<xsl:variable name="graphTitle" select="/graph/@title"/>
	<xsl:variable name="graphLegend" select="/graph/@legend"/>
	<xsl:variable name="graphXTitle" select="/graph/@xTitle"/>
	<xsl:variable name="graphYTitle" select="/graph/@yTitle"/>
	<xsl:variable name="graphTopValPerc" select="/graph/@topValPerc"/>
	<xsl:variable name="graphBgColor" select="/graph/@bgColor"/>
	<!--
	===========================================================================
		Some counts
	===========================================================================-->
	<xsl:variable name="seriesCount" select="count(/graph/series)"/>
	<xsl:variable name="valueCount" select="count(/graph/series[1]/value)"/>
	<xsl:variable name="supportForMinMax">
		<xsl:choose>
			<xsl:when test="function-available('math:min') and function-available('math:max')">yes</xsl:when>
			<xsl:otherwise>
				<xsl:message terminate="yes">
					<xsl:text>Your XSLT processor does not support math:min or math:max functions!</xsl:text>
					<xsl:text>Use some exslt powered processor instead, SAXON for example.</xsl:text>
				</xsl:message>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="maxValue" select="math:max(//value)"/>
	<!--
	===========================================================================
		The trick enabling even the smallest values to be visible
	===========================================================================-->
	<xsl:variable name="minValueTMP" select="math:min(//value)"/>
	<xsl:variable name="minValue">
		<xsl:choose>
			<xsl:when test="$minValueTMP>0">0</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$minValueTMP -1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="valueRange" select="$maxValue -$minValue"/>
	<!--
	===========================================================================
		Zero-indicating line coordinate - may be needed to draw zero-indicating line
	===========================================================================-->
	<xsl:variable name="zeroLineCoord" select="1000-(-$minValue div $valueRange)*10*$graphTopValPerc"/>
	<!--
	===========================================================================
		Values of top, middle and bottom grid points
	===========================================================================-->
	<xsl:variable name="topValueTMP" select="round($maxValue+($valueRange div ($graphTopValPerc div 100))-$valueRange)"/>
	<xsl:variable name="bottomValueTMP" select="round($minValue)"/>
	<xsl:variable name="midValueTMP" select="round(($topValue+$bottomValue) div 2)"/>
	
	<xsl:variable name="topValue" select="round($maxValue+($valueRange div ($graphTopValPerc div 100))-$valueRange)"/>
	<xsl:variable name="bottomValue" select="round($minValue)"/>
	<!--
	===========================================================================
		Values of top, middle and bottom grid points
	===========================================================================-->
	<xsl:variable name="midValue" select="round(($topValue+$bottomValue) div 2)"/>
	<!--
	===========================================================================
		Middle grid point coordinate
	===========================================================================-->
	<xsl:variable name="midValueCoord" select="1000-(($midValue -$minValue)*((10*$graphTopValPerc) div $valueRange))"/>
	<!--
	===========================================================================
		Width of an drawing element rectangle
	===========================================================================-->
	<xsl:variable name="elementWidth" select="1000 div ($seriesCount*$valueCount+$valueCount+1)"/>
</xsl:stylesheet>
